"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

The Tethering domain defines methods and events for browser port binding.
https://chromedevtools.github.io/devtools-protocol/tot/Tethering/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol.base import CDPEvent


class Accepted(CDPEvent):
    """ Informs that port was successfully bound and got a specified connection id. """

    port: int
    connectionId: str



from .methods import GetFeatureState, GetInfo, GetProcessInfo
from .types import (
    GPUDevice,
    GPUInfo,
    ImageType,
    ProcessInfo,
    Size,
    SubsamplingFormat,
    VideoDecodeAcceleratorCapability,
    VideoEncodeAcceleratorCapability,
)

__all__ = [
    GPUDevice,
    Size,
    VideoDecodeAcceleratorCapability,
    VideoEncodeAcceleratorCapability,
    SubsamplingFormat,
    ImageType,
    GPUInfo,
    ProcessInfo,
    GetInfo,
    GetFeatureState,
    GetProcessInfo,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Query and modify DOM storage.
https://chromedevtools.github.io/devtools-protocol/tot/DOMStorage/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOMStorageItem,
    DOMStorageSerializedStorageKey,
    DOMStorageStorageId,
)

SerializedStorageKey = DOMStorageSerializedStorageKey
StorageId = DOMStorageStorageId
Item = DOMStorageItem



from .events import BackgroundServiceEventReceived, RecordingStateChanged
from .methods import ClearEvents, SetRecording, StartObserving, StopObserving
from .types import BackgroundServiceEvent, EventMetadata, ServiceName

__all__ = [
    ServiceName,
    EventMetadata,
    BackgroundServiceEvent,
    RecordingStateChanged,
    BackgroundServiceEventReceived,
    StartObserving,
    StopObserving,
    SetRecording,
    ClearEvents,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Runtime domain exposes JavaScript runtime by means of remote evaluation and mirror objects.
Evaluation results are returned as mirror object that expose object type, string representation
and unique identifier that can be used for further object reference. Original objects are
maintained in memory unless they are either explicitly released or are released along with the
other objects in their object group.
https://chromedevtools.github.io/devtools-protocol/tot/Runtime/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    Runtime,
)
from cdpkit.protocol.base import JSON_DICT, CDPEvent


class BindingCalled(CDPEvent):
    """ Notification is issued every time when binding is called. """

    name: str
    payload: str
    executionContextId: Runtime.ExecutionContextId


class ConsoleAPICalled(CDPEvent):
    """ Issued when console API was called. """

    type: Literal['log', 'debug', 'info', 'error', 'warning', 'dir', 'dirxml', 'table', 'trace', 'clear', 'startGroup', 'startGroupCollapsed', 'endGroup', 'assert', 'profile', 'profileEnd', 'count', 'timeEnd']
    args: list[Runtime.RemoteObject]
    executionContextId: Runtime.ExecutionContextId
    timestamp: Runtime.Timestamp
    stackTrace: Runtime.StackTrace | None = None
    context: str | None = None  # experimental


class ExceptionRevoked(CDPEvent):
    """ Issued when unhandled exception was revoked. """

    reason: str
    exceptionId: int


class ExceptionThrown(CDPEvent):
    """ Issued when exception was thrown and unhandled. """

    timestamp: Runtime.Timestamp
    exceptionDetails: Runtime.ExceptionDetails


class ExecutionContextCreated(CDPEvent):
    """ Issued when new execution context is created. """

    context: Runtime.ExecutionContextDescription


class ExecutionContextDestroyed(CDPEvent):
    """ Issued when execution context is destroyed. """

    executionContextId: Runtime.ExecutionContextId  # deprecated
    executionContextUniqueId: str | None = None  # experimental


class ExecutionContextsCleared(CDPEvent):
    """ Issued when all executionContexts were cleared in browser """

    ...


class InspectRequested(CDPEvent):
    """ Issued when object should be inspected (for example, as a result of inspect() command line API
    call). """

    object: Runtime.RemoteObject
    hints: JSON_DICT
    executionContextId: Runtime.ExecutionContextId | None = None  # experimental



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Storage/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    StorageAttributionReportingAggregatableDebugReportingConfig,
    StorageAttributionReportingAggregatableDebugReportingData,
    StorageAttributionReportingAggregatableDedupKey,
    StorageAttributionReportingAggregatableResult,
    StorageAttributionReportingAggregatableTriggerData,
    StorageAttributionReportingAggregatableValueDictEntry,
    StorageAttributionReportingAggregatableValueEntry,
    StorageAttributionReportingAggregationKeysEntry,
    StorageAttributionReportingEventLevelResult,
    StorageAttributionReportingEventReportWindows,
    StorageAttributionReportingEventTriggerData,
    StorageAttributionReportingFilterConfig,
    StorageAttributionReportingFilterDataEntry,
    StorageAttributionReportingFilterPair,
    StorageAttributionReportingNamedBudgetCandidate,
    StorageAttributionReportingNamedBudgetDef,
    StorageAttributionReportingReportResult,
    StorageAttributionReportingSourceRegistration,
    StorageAttributionReportingSourceRegistrationResult,
    StorageAttributionReportingSourceRegistrationTimeConfig,
    StorageAttributionReportingSourceType,
    StorageAttributionReportingTriggerDataMatching,
    StorageAttributionReportingTriggerRegistration,
    StorageAttributionScopesData,
    StorageInterestGroupAccessType,
    StorageInterestGroupAuctionEventType,
    StorageInterestGroupAuctionFetchType,
    StorageInterestGroupAuctionId,
    StorageRelatedWebsiteSet,
    StorageSerializedStorageKey,
    StorageSharedStorageAccessMethod,
    StorageSharedStorageAccessParams,
    StorageSharedStorageAccessScope,
    StorageSharedStorageEntry,
    StorageSharedStorageMetadata,
    StorageSharedStoragePrivateAggregationConfig,
    StorageSharedStorageReportingMetadata,
    StorageSharedStorageUrlWithMetadata,
    StorageSignedInt64AsBase10,
    StorageStorageBucket,
    StorageStorageBucketInfo,
    StorageStorageBucketsDurability,
    StorageStorageType,
    StorageTrustTokens,
    StorageUnsignedInt64AsBase10,
    StorageUnsignedInt128AsBase16,
    StorageUsageForType,
)

SerializedStorageKey = StorageSerializedStorageKey
StorageType = StorageStorageType
UsageForType = StorageUsageForType
TrustTokens = StorageTrustTokens
InterestGroupAuctionId = StorageInterestGroupAuctionId
InterestGroupAccessType = StorageInterestGroupAccessType
InterestGroupAuctionEventType = StorageInterestGroupAuctionEventType
InterestGroupAuctionFetchType = StorageInterestGroupAuctionFetchType
SharedStorageAccessScope = StorageSharedStorageAccessScope
SharedStorageAccessMethod = StorageSharedStorageAccessMethod
SharedStorageEntry = StorageSharedStorageEntry
SharedStorageMetadata = StorageSharedStorageMetadata
SharedStoragePrivateAggregationConfig = StorageSharedStoragePrivateAggregationConfig
SharedStorageReportingMetadata = StorageSharedStorageReportingMetadata
SharedStorageUrlWithMetadata = StorageSharedStorageUrlWithMetadata
SharedStorageAccessParams = StorageSharedStorageAccessParams
StorageBucketsDurability = StorageStorageBucketsDurability
StorageBucket = StorageStorageBucket
StorageBucketInfo = StorageStorageBucketInfo
AttributionReportingSourceType = StorageAttributionReportingSourceType
UnsignedInt64AsBase10 = StorageUnsignedInt64AsBase10
UnsignedInt128AsBase16 = StorageUnsignedInt128AsBase16
SignedInt64AsBase10 = StorageSignedInt64AsBase10
AttributionReportingFilterDataEntry = StorageAttributionReportingFilterDataEntry
AttributionReportingFilterConfig = StorageAttributionReportingFilterConfig
AttributionReportingFilterPair = StorageAttributionReportingFilterPair
AttributionReportingAggregationKeysEntry = StorageAttributionReportingAggregationKeysEntry
AttributionReportingEventReportWindows = StorageAttributionReportingEventReportWindows
AttributionReportingTriggerDataMatching = StorageAttributionReportingTriggerDataMatching
AttributionReportingAggregatableDebugReportingData = StorageAttributionReportingAggregatableDebugReportingData
AttributionReportingAggregatableDebugReportingConfig = StorageAttributionReportingAggregatableDebugReportingConfig
AttributionScopesData = StorageAttributionScopesData
AttributionReportingNamedBudgetDef = StorageAttributionReportingNamedBudgetDef
AttributionReportingSourceRegistration = StorageAttributionReportingSourceRegistration
AttributionReportingSourceRegistrationResult = StorageAttributionReportingSourceRegistrationResult
AttributionReportingSourceRegistrationTimeConfig = StorageAttributionReportingSourceRegistrationTimeConfig
AttributionReportingAggregatableValueDictEntry = StorageAttributionReportingAggregatableValueDictEntry
AttributionReportingAggregatableValueEntry = StorageAttributionReportingAggregatableValueEntry
AttributionReportingEventTriggerData = StorageAttributionReportingEventTriggerData
AttributionReportingAggregatableTriggerData = StorageAttributionReportingAggregatableTriggerData
AttributionReportingAggregatableDedupKey = StorageAttributionReportingAggregatableDedupKey
AttributionReportingNamedBudgetCandidate = StorageAttributionReportingNamedBudgetCandidate
AttributionReportingTriggerRegistration = StorageAttributionReportingTriggerRegistration
AttributionReportingEventLevelResult = StorageAttributionReportingEventLevelResult
AttributionReportingAggregatableResult = StorageAttributionReportingAggregatableResult
AttributionReportingReportResult = StorageAttributionReportingReportResult
RelatedWebsiteSet = StorageRelatedWebsiteSet



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/LayerTree/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    LayerTreeLayer,
    LayerTreeLayerId,
    LayerTreePaintProfile,
    LayerTreePictureTile,
    LayerTreeScrollRect,
    LayerTreeSnapshotId,
    LayerTreeStickyPositionConstraint,
)

LayerId = LayerTreeLayerId
SnapshotId = LayerTreeSnapshotId
ScrollRect = LayerTreeScrollRect
StickyPositionConstraint = LayerTreeStickyPositionConstraint
PictureTile = LayerTreePictureTile
Layer = LayerTreeLayer
PaintProfile = LayerTreePaintProfile



from .events import PlayerCreated, PlayerErrorsRaised, PlayerEventsAdded, PlayerMessagesLogged, PlayerPropertiesChanged
from .methods import Disable, Enable
from .types import (
    Player,
    PlayerError,
    PlayerErrorSourceLocation,
    PlayerEvent,
    PlayerId,
    PlayerMessage,
    PlayerProperty,
    Timestamp,
)

__all__ = [
    PlayerId,
    Timestamp,
    PlayerMessage,
    PlayerProperty,
    PlayerEvent,
    PlayerErrorSourceLocation,
    PlayerError,
    Player,
    PlayerPropertiesChanged,
    PlayerEventsAdded,
    PlayerMessagesLogged,
    PlayerErrorsRaised,
    PlayerCreated,
    Enable,
    Disable,
]



"""
This file is generated by generator/run.py with chrome-devtools-protocol.

The Tethering domain defines methods and events for browser port binding.
https://chromedevtools.github.io/devtools-protocol/tot/Tethering/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Profiler/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    ProfilerCoverageRange,
    ProfilerFunctionCoverage,
    ProfilerPositionTickInfo,
    ProfilerProfile,
    ProfilerProfileNode,
    ProfilerScriptCoverage,
)

ProfileNode = ProfilerProfileNode
Profile = ProfilerProfile
PositionTickInfo = ProfilerPositionTickInfo
CoverageRange = ProfilerCoverageRange
FunctionCoverage = ProfilerFunctionCoverage
ScriptCoverage = ProfilerScriptCoverage



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing
breakpoints, stepping through execution, exploring stack traces, etc.
https://chromedevtools.github.io/devtools-protocol/tot/Debugger/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DebuggerBreakLocation,
    DebuggerBreakpointId,
    DebuggerCallFrame,
    DebuggerCallFrameId,
    DebuggerDebugSymbols,
    DebuggerLocation,
    DebuggerLocationRange,
    DebuggerResolvedBreakpoint,
    DebuggerScope,
    DebuggerScriptLanguage,
    DebuggerScriptPosition,
    DebuggerSearchMatch,
    DebuggerWasmDisassemblyChunk,
)

BreakpointId = DebuggerBreakpointId
CallFrameId = DebuggerCallFrameId
Location = DebuggerLocation
ScriptPosition = DebuggerScriptPosition
LocationRange = DebuggerLocationRange
CallFrame = DebuggerCallFrame
Scope = DebuggerScope
SearchMatch = DebuggerSearchMatch
BreakLocation = DebuggerBreakLocation
WasmDisassemblyChunk = DebuggerWasmDisassemblyChunk
ScriptLanguage = DebuggerScriptLanguage
DebugSymbols = DebuggerDebugSymbols
ResolvedBreakpoint = DebuggerResolvedBreakpoint



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/LayerTree/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOM,
    LayerTree,
)
from cdpkit.protocol.base import JSON_DICT, CDPMethod, InputModel, OutputModel


class CompositingReasonsInput(InputModel):

    layerId: LayerTree.LayerId


class CompositingReasonsOutput(OutputModel):

    compositingReasons: list[str]
    compositingReasonIds: list[str]


class CompositingReasons(CDPMethod[CompositingReasonsOutput]):
    """ Provides the reasons why the given layer was composited. """

    INPUT_VALIDATOR = CompositingReasonsInput
    OUTPUT_VALIDATOR = CompositingReasonsOutput

    def __init__(
        self,
        *,
        layer_id: LayerTree.LayerId
    ):
        super().__init__(
            layerId=layer_id
        )


class Disable(CDPMethod[None]):
    """ Disables compositing tree inspection. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Enable(CDPMethod[None]):
    """ Enables compositing tree inspection. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class LoadSnapshotInput(InputModel):

    tiles: list[LayerTree.PictureTile]


class LoadSnapshotOutput(OutputModel):

    snapshotId: LayerTree.SnapshotId


class LoadSnapshot(CDPMethod[LoadSnapshotOutput]):
    """ Returns the snapshot identifier. """

    INPUT_VALIDATOR = LoadSnapshotInput
    OUTPUT_VALIDATOR = LoadSnapshotOutput

    def __init__(
        self,
        *,
        tiles: list[LayerTree.PictureTile]
    ):
        super().__init__(
            tiles=tiles
        )


class MakeSnapshotInput(InputModel):

    layerId: LayerTree.LayerId


class MakeSnapshotOutput(OutputModel):

    snapshotId: LayerTree.SnapshotId


class MakeSnapshot(CDPMethod[MakeSnapshotOutput]):
    """ Returns the layer snapshot identifier. """

    INPUT_VALIDATOR = MakeSnapshotInput
    OUTPUT_VALIDATOR = MakeSnapshotOutput

    def __init__(
        self,
        *,
        layer_id: LayerTree.LayerId
    ):
        super().__init__(
            layerId=layer_id
        )


class ProfileSnapshotInput(InputModel):

    snapshotId: LayerTree.SnapshotId
    minRepeatCount: int | None = None
    minDuration: float | None = None
    clipRect: DOM.Rect | None = None


class ProfileSnapshotOutput(OutputModel):

    timings: list[LayerTree.PaintProfile]


class ProfileSnapshot(CDPMethod[ProfileSnapshotOutput]):

    INPUT_VALIDATOR = ProfileSnapshotInput
    OUTPUT_VALIDATOR = ProfileSnapshotOutput

    def __init__(
        self,
        *,
        snapshot_id: LayerTree.SnapshotId,
        min_repeat_count: int | None = None,
        min_duration: float | None = None,
        clip_rect: DOM.Rect | None = None
    ):
        super().__init__(
            snapshotId=snapshot_id,
            minRepeatCount=min_repeat_count,
            minDuration=min_duration,
            clipRect=clip_rect
        )


class ReleaseSnapshotInput(InputModel):

    snapshotId: LayerTree.SnapshotId


class ReleaseSnapshot(CDPMethod[None]):
    """ Releases layer snapshot captured by the back-end. """

    INPUT_VALIDATOR = ReleaseSnapshotInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        snapshot_id: LayerTree.SnapshotId
    ):
        super().__init__(
            snapshotId=snapshot_id
        )


class ReplaySnapshotInput(InputModel):

    snapshotId: LayerTree.SnapshotId
    fromStep: int | None = None
    toStep: int | None = None
    scale: float | None = None


class ReplaySnapshotOutput(OutputModel):

    dataURL: str


class ReplaySnapshot(CDPMethod[ReplaySnapshotOutput]):
    """ Replays the layer snapshot and returns the resulting bitmap. """

    INPUT_VALIDATOR = ReplaySnapshotInput
    OUTPUT_VALIDATOR = ReplaySnapshotOutput

    def __init__(
        self,
        *,
        snapshot_id: LayerTree.SnapshotId,
        from_step: int | None = None,
        to_step: int | None = None,
        scale: float | None = None
    ):
        super().__init__(
            snapshotId=snapshot_id,
            fromStep=from_step,
            toStep=to_step,
            scale=scale
        )


class SnapshotCommandLogInput(InputModel):

    snapshotId: LayerTree.SnapshotId


class SnapshotCommandLogOutput(OutputModel):

    commandLog: list[JSON_DICT]


class SnapshotCommandLog(CDPMethod[SnapshotCommandLogOutput]):
    """ Replays the layer snapshot and returns canvas log. """

    INPUT_VALIDATOR = SnapshotCommandLogInput
    OUTPUT_VALIDATOR = SnapshotCommandLogOutput

    def __init__(
        self,
        *,
        snapshot_id: LayerTree.SnapshotId
    ):
        super().__init__(
            snapshotId=snapshot_id
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/ServiceWorker/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    ServiceWorker,
)
from cdpkit.protocol.base import CDPEvent


class WorkerErrorReported(CDPEvent):

    errorMessage: ServiceWorker.ServiceWorkerErrorMessage


class WorkerRegistrationUpdated(CDPEvent):

    registrations: list[ServiceWorker.ServiceWorkerRegistration]


class WorkerVersionUpdated(CDPEvent):

    versions: list[ServiceWorker.ServiceWorkerVersion]



from .events import Metrics
from .methods import Disable, Enable, GetMetrics, SetTimeDomain
from .types import Metric

__all__ = [
    Metric,
    Metrics,
    Disable,
    Enable,
    SetTimeDomain,
    GetMetrics,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Defines commands and events for Autofill.
https://chromedevtools.github.io/devtools-protocol/tot/Autofill/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Autofill,
)
from cdpkit.protocol.base import CDPEvent


class AddressFormFilled(CDPEvent):
    """ Emitted when an address form is filled. """

    filledFields: list[Autofill.FilledField]
    addressUi: Autofill.AddressUI



from .events import DownloadProgress, DownloadWillBegin
from .methods import (
    AddPrivacySandboxCoordinatorKeyConfig,
    AddPrivacySandboxEnrollmentOverride,
    CancelDownload,
    Close,
    Crash,
    CrashGpuProcess,
    ExecuteBrowserCommand,
    GetBrowserCommandLine,
    GetHistogram,
    GetHistograms,
    GetVersion,
    GetWindowBounds,
    GetWindowForTarget,
    GrantPermissions,
    ResetPermissions,
    SetContentsSize,
    SetDockTile,
    SetDownloadBehavior,
    SetPermission,
    SetWindowBounds,
)
from .types import (
    Bounds,
    BrowserCommandId,
    BrowserContextID,
    Bucket,
    Histogram,
    PermissionDescriptor,
    PermissionSetting,
    PermissionType,
    PrivacySandboxAPI,
    WindowID,
    WindowState,
)

__all__ = [
    BrowserContextID,
    WindowID,
    WindowState,
    Bounds,
    PermissionType,
    PermissionSetting,
    PermissionDescriptor,
    BrowserCommandId,
    Bucket,
    Histogram,
    PrivacySandboxAPI,
    DownloadWillBegin,
    DownloadProgress,
    SetPermission,
    GrantPermissions,
    ResetPermissions,
    SetDownloadBehavior,
    CancelDownload,
    Close,
    Crash,
    CrashGpuProcess,
    GetVersion,
    GetBrowserCommandLine,
    GetHistograms,
    GetHistogram,
    GetWindowBounds,
    GetWindowForTarget,
    SetWindowBounds,
    SetContentsSize,
    SetDockTile,
    ExecuteBrowserCommand,
    AddPrivacySandboxEnrollmentOverride,
    AddPrivacySandboxCoordinatorKeyConfig,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain provides experimental commands only supported in headless mode.
https://chromedevtools.github.io/devtools-protocol/tot/HeadlessExperimental/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    HeadlessExperimentalScreenshotParams,
)

ScreenshotParams = HeadlessExperimentalScreenshotParams



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Actions and events related to the inspected page belong to the page domain.
https://chromedevtools.github.io/devtools-protocol/tot/Page/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    DOM,
    Network,
    Page,
    Runtime,
)
from cdpkit.protocol.base import CDPEvent


class DomContentEventFired(CDPEvent):

    timestamp: Network.MonotonicTime


class FileChooserOpened(CDPEvent):
    """ Emitted only when `page.interceptFileChooser` is enabled. """

    frameId: Page.FrameId | None = None  # experimental
    mode: Literal['selectSingle', 'selectMultiple']
    backendNodeId: DOM.BackendNodeId | None = None  # experimental


class FrameAttached(CDPEvent):
    """ Fired when frame has been attached to its parent. """

    frameId: Page.FrameId
    parentFrameId: Page.FrameId
    stack: Runtime.StackTrace | None = None


class FrameClearedScheduledNavigation(CDPEvent):
    """ Fired when frame no longer has a scheduled navigation. """

    frameId: Page.FrameId


class FrameDetached(CDPEvent):
    """ Fired when frame has been detached from its parent. """

    frameId: Page.FrameId
    reason: Literal['remove', 'swap'] | None = None  # experimental


class FrameSubtreeWillBeDetached(CDPEvent):
    """ Fired before frame subtree is detached. Emitted before any frame of the
    subtree is actually detached. """

    frameId: Page.FrameId


class FrameNavigated(CDPEvent):
    """ Fired once navigation of the frame has completed. Frame is now associated with the new loader. """

    frame: Page.Frame
    type: Page.NavigationType | None = None  # experimental


class DocumentOpened(CDPEvent):
    """ Fired when opening document to write to. """

    frame: Page.Frame


class FrameResized(CDPEvent):

    ...


class FrameStartedNavigating(CDPEvent):
    """ Fired when a navigation starts. This event is fired for both
    renderer-initiated and browser-initiated navigations. For renderer-initiated
    navigations, the event is fired after `frameRequestedNavigation`.
    Navigation may still be cancelled after the event is issued. Multiple events
    can be fired for a single navigation, for example, when a same-document
    navigation becomes a cross-document navigation (such as in the case of a
    frameset). """

    frameId: Page.FrameId
    url: str
    loaderId: Network.LoaderId
    navigationType: Literal['reload', 'reloadBypassingCache', 'restore', 'restoreWithPost', 'historySameDocument', 'historyDifferentDocument', 'sameDocument', 'differentDocument']


class FrameRequestedNavigation(CDPEvent):
    """ Fired when a renderer-initiated navigation is requested.
    Navigation may still be cancelled after the event is issued. """

    frameId: Page.FrameId
    reason: Page.ClientNavigationReason
    url: str
    disposition: Page.ClientNavigationDisposition


class FrameScheduledNavigation(CDPEvent):
    """ Fired when frame schedules a potential navigation. """

    frameId: Page.FrameId
    delay: float
    reason: Page.ClientNavigationReason
    url: str


class FrameStartedLoading(CDPEvent):
    """ Fired when frame has started loading. """

    frameId: Page.FrameId


class FrameStoppedLoading(CDPEvent):
    """ Fired when frame has stopped loading. """

    frameId: Page.FrameId


class DownloadWillBegin(CDPEvent):
    """ Fired when page is about to start a download.
    Deprecated. Use Browser.downloadWillBegin instead. """

    frameId: Page.FrameId
    guid: str
    url: str
    suggestedFilename: str


class DownloadProgress(CDPEvent):
    """ Fired when download makes progress. Last call has |done| == true.
    Deprecated. Use Browser.downloadProgress instead. """

    guid: str
    totalBytes: float
    receivedBytes: float
    state: Literal['inProgress', 'completed', 'canceled']


class InterstitialHidden(CDPEvent):
    """ Fired when interstitial page was hidden """

    ...


class InterstitialShown(CDPEvent):
    """ Fired when interstitial page was shown """

    ...


class JavascriptDialogClosed(CDPEvent):
    """ Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) has been
    closed. """

    frameId: Page.FrameId | None = None  # experimental
    result: bool
    userInput: str


class JavascriptDialogOpening(CDPEvent):
    """ Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) is about to
    open. """

    url: str
    frameId: Page.FrameId | None = None  # experimental
    message: str
    type: Page.DialogType
    hasBrowserHandler: bool
    defaultPrompt: str | None = None


class LifecycleEvent(CDPEvent):
    """ Fired for lifecycle events (navigation, load, paint, etc) in the current
    target (including local frames). """

    frameId: Page.FrameId
    loaderId: Network.LoaderId
    name: str
    timestamp: Network.MonotonicTime


class BackForwardCacheNotUsed(CDPEvent):
    """ Fired for failed bfcache history navigations if BackForwardCache feature is enabled. Do
    not assume any ordering with the Page.frameNavigated event. This event is fired only for
    main-frame history navigation where the document changes (non-same-document navigations),
    when bfcache navigation fails. """

    loaderId: Network.LoaderId
    frameId: Page.FrameId
    notRestoredExplanations: list[Page.BackForwardCacheNotRestoredExplanation]
    notRestoredExplanationsTree: Page.BackForwardCacheNotRestoredExplanationTree | None = None


class LoadEventFired(CDPEvent):

    timestamp: Network.MonotonicTime


class NavigatedWithinDocument(CDPEvent):
    """ Fired when same-document navigation happens, e.g. due to history API usage or anchor navigation. """

    frameId: Page.FrameId
    url: str
    navigationType: Literal['fragment', 'historyApi', 'other']


class ScreencastFrame(CDPEvent):
    """ Compressed image data requested by the `startScreencast`. """

    data: str
    metadata: Page.ScreencastFrameMetadata
    sessionId: int


class ScreencastVisibilityChanged(CDPEvent):
    """ Fired when the page with currently enabled screencast was shown or hidden `. """

    visible: bool


class WindowOpen(CDPEvent):
    """ Fired when a new window is going to be opened, via window.open(), link click, form submission,
    etc. """

    url: str
    windowName: str
    windowFeatures: list[str]
    userGesture: bool


class CompilationCacheProduced(CDPEvent):
    """ Issued for every compilation cache generated. """

    url: str
    data: str



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Defines events for background web platform features.
https://chromedevtools.github.io/devtools-protocol/tot/BackgroundService/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    BackgroundServiceBackgroundServiceEvent,
    BackgroundServiceEventMetadata,
    BackgroundServiceServiceName,
)

ServiceName = BackgroundServiceServiceName
EventMetadata = BackgroundServiceEventMetadata
BackgroundServiceEvent = BackgroundServiceBackgroundServiceEvent



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain facilitates obtaining document snapshots with DOM, layout, and style information.
https://chromedevtools.github.io/devtools-protocol/tot/DOMSnapshot/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Accessibility/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    AccessibilityAXNode,
    AccessibilityAXNodeId,
    AccessibilityAXProperty,
    AccessibilityAXPropertyName,
    AccessibilityAXRelatedNode,
    AccessibilityAXValue,
    AccessibilityAXValueNativeSourceType,
    AccessibilityAXValueSource,
    AccessibilityAXValueSourceType,
    AccessibilityAXValueType,
)

AXNodeId = AccessibilityAXNodeId
AXValueType = AccessibilityAXValueType
AXValueSourceType = AccessibilityAXValueSourceType
AXValueNativeSourceType = AccessibilityAXValueNativeSourceType
AXValueSource = AccessibilityAXValueSource
AXRelatedNode = AccessibilityAXRelatedNode
AXProperty = AccessibilityAXProperty
AXValue = AccessibilityAXValue
AXPropertyName = AccessibilityAXPropertyName
AXNode = AccessibilityAXNode



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    HeapProfilerHeapSnapshotObjectId,
    HeapProfilerSamplingHeapProfile,
    HeapProfilerSamplingHeapProfileNode,
    HeapProfilerSamplingHeapProfileSample,
)

HeapSnapshotObjectId = HeapProfilerHeapSnapshotObjectId
SamplingHeapProfileNode = HeapProfilerSamplingHeapProfileNode
SamplingHeapProfileSample = HeapProfilerSamplingHeapProfileSample
SamplingHeapProfile = HeapProfilerSamplingHeapProfile



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Storage/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Network,
    Page,
    Storage,
    Target,
)
from cdpkit.protocol.base import JSON_DICT, CDPEvent


class CacheStorageContentUpdated(CDPEvent):
    """ A cache's contents have been modified. """

    origin: str
    storageKey: str
    bucketId: str
    cacheName: str


class CacheStorageListUpdated(CDPEvent):
    """ A cache has been added/deleted. """

    origin: str
    storageKey: str
    bucketId: str


class IndexedDBContentUpdated(CDPEvent):
    """ The origin's IndexedDB object store has been modified. """

    origin: str
    storageKey: str
    bucketId: str
    databaseName: str
    objectStoreName: str


class IndexedDBListUpdated(CDPEvent):
    """ The origin's IndexedDB database list has been modified. """

    origin: str
    storageKey: str
    bucketId: str


class InterestGroupAccessed(CDPEvent):
    """ One of the interest groups was accessed. Note that these events are global
    to all targets sharing an interest group store. """

    accessTime: Network.TimeSinceEpoch
    type: Storage.InterestGroupAccessType
    ownerOrigin: str
    name: str
    componentSellerOrigin: str | None = None
    bid: float | None = None
    bidCurrency: str | None = None
    uniqueAuctionId: Storage.InterestGroupAuctionId | None = None


class InterestGroupAuctionEventOccurred(CDPEvent):
    """ An auction involving interest groups is taking place. These events are
    target-specific. """

    eventTime: Network.TimeSinceEpoch
    type: Storage.InterestGroupAuctionEventType
    uniqueAuctionId: Storage.InterestGroupAuctionId
    parentAuctionId: Storage.InterestGroupAuctionId | None = None
    auctionConfig: JSON_DICT | None = None


class InterestGroupAuctionNetworkRequestCreated(CDPEvent):
    """ Specifies which auctions a particular network fetch may be related to, and
    in what role. Note that it is not ordered with respect to
    Network.requestWillBeSent (but will happen before loadingFinished
    loadingFailed). """

    type: Storage.InterestGroupAuctionFetchType
    requestId: Network.RequestId
    auctions: list[Storage.InterestGroupAuctionId]


class SharedStorageAccessed(CDPEvent):
    """ Shared storage was accessed by the associated page.
    The following parameters are included in all events. """

    accessTime: Network.TimeSinceEpoch
    scope: Storage.SharedStorageAccessScope
    method: Storage.SharedStorageAccessMethod
    mainFrameId: Page.FrameId
    ownerOrigin: str
    ownerSite: str
    params: Storage.SharedStorageAccessParams


class SharedStorageWorkletOperationExecutionFinished(CDPEvent):
    """ A shared storage run or selectURL operation finished its execution.
    The following parameters are included in all events. """

    finishedTime: Network.TimeSinceEpoch
    executionTime: int
    method: Storage.SharedStorageAccessMethod
    operationId: str
    workletTargetId: Target.TargetID
    mainFrameId: Page.FrameId
    ownerOrigin: str


class StorageBucketCreatedOrUpdated(CDPEvent):

    bucketInfo: Storage.StorageBucketInfo


class StorageBucketDeleted(CDPEvent):

    bucketId: str


class AttributionReportingSourceRegistered(CDPEvent):

    registration: Storage.AttributionReportingSourceRegistration
    result: Storage.AttributionReportingSourceRegistrationResult


class AttributionReportingTriggerRegistered(CDPEvent):

    registration: Storage.AttributionReportingTriggerRegistration
    eventLevel: Storage.AttributionReportingEventLevelResult
    aggregatable: Storage.AttributionReportingAggregatableResult


class AttributionReportingReportSent(CDPEvent):

    url: str
    body: JSON_DICT
    result: Storage.AttributionReportingReportResult
    netError: int | None = None
    netErrorName: str | None = None
    httpStatusCode: int | None = None


class AttributionReportingVerboseDebugReportSent(CDPEvent):

    url: str
    body: list[JSON_DICT] | None = None
    netError: int | None = None
    netErrorName: str | None = None
    httpStatusCode: int | None = None



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Supports additional targets discovery and allows to attach to them.
https://chromedevtools.github.io/devtools-protocol/tot/Target/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Target,
)
from cdpkit.protocol.base import CDPEvent


class AttachedToTarget(CDPEvent):
    """ Issued when attached to target because of auto-attach or `attachToTarget` command. """

    sessionId: Target.SessionID
    targetInfo: Target.TargetInfo
    waitingForDebugger: bool


class DetachedFromTarget(CDPEvent):
    """ Issued when detached from target for any reason (including `detachFromTarget` command). Can be
    issued multiple times per target if multiple sessions have been attached to it. """

    sessionId: Target.SessionID
    targetId: Target.TargetID | None = None  # deprecated


class ReceivedMessageFromTarget(CDPEvent):
    """ Notifies about a new protocol message received from the session (as reported in
    `attachedToTarget` event). """

    sessionId: Target.SessionID
    message: str
    targetId: Target.TargetID | None = None  # deprecated


class TargetCreated(CDPEvent):
    """ Issued when a possible inspection target is created. """

    targetInfo: Target.TargetInfo


class TargetDestroyed(CDPEvent):
    """ Issued when a target is destroyed. """

    targetId: Target.TargetID


class TargetCrashed(CDPEvent):
    """ Issued when a target has crashed. """

    targetId: Target.TargetID
    status: str
    errorCode: int


class TargetInfoChanged(CDPEvent):
    """ Issued when some information about a target has changed. This only happens between
    `targetCreated` and `targetDestroyed`. """

    targetInfo: Target.TargetInfo



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    HeapProfiler,
    Runtime,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class AddInspectedHeapObjectInput(InputModel):

    heapObjectId: HeapProfiler.HeapSnapshotObjectId


class AddInspectedHeapObject(CDPMethod[None]):
    """ Enables console to refer to the node with given id via $x (see Command Line API for more details
    $x functions). """

    INPUT_VALIDATOR = AddInspectedHeapObjectInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        heap_object_id: HeapProfiler.HeapSnapshotObjectId
    ):
        super().__init__(
            heapObjectId=heap_object_id
        )


class CollectGarbage(CDPMethod[None]):

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Disable(CDPMethod[None]):

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Enable(CDPMethod[None]):

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class GetHeapObjectIdInput(InputModel):

    objectId: Runtime.RemoteObjectId


class GetHeapObjectIdOutput(OutputModel):

    heapSnapshotObjectId: HeapProfiler.HeapSnapshotObjectId


class GetHeapObjectId(CDPMethod[GetHeapObjectIdOutput]):

    INPUT_VALIDATOR = GetHeapObjectIdInput
    OUTPUT_VALIDATOR = GetHeapObjectIdOutput

    def __init__(
        self,
        *,
        object_id: Runtime.RemoteObjectId
    ):
        super().__init__(
            objectId=object_id
        )


class GetObjectByHeapObjectIdInput(InputModel):

    objectId: HeapProfiler.HeapSnapshotObjectId
    objectGroup: str | None = None


class GetObjectByHeapObjectIdOutput(OutputModel):

    result: Runtime.RemoteObject


class GetObjectByHeapObjectId(CDPMethod[GetObjectByHeapObjectIdOutput]):

    INPUT_VALIDATOR = GetObjectByHeapObjectIdInput
    OUTPUT_VALIDATOR = GetObjectByHeapObjectIdOutput

    def __init__(
        self,
        *,
        object_id: HeapProfiler.HeapSnapshotObjectId,
        object_group: str | None = None
    ):
        super().__init__(
            objectId=object_id,
            objectGroup=object_group
        )


class GetSamplingProfileOutput(OutputModel):

    profile: HeapProfiler.SamplingHeapProfile


class GetSamplingProfile(CDPMethod[GetSamplingProfileOutput]):

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetSamplingProfileOutput


class StartSamplingInput(InputModel):

    samplingInterval: float | None = None
    stackDepth: float | None = None
    includeObjectsCollectedByMajorGC: bool | None = None
    includeObjectsCollectedByMinorGC: bool | None = None


class StartSampling(CDPMethod[None]):

    INPUT_VALIDATOR = StartSamplingInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        sampling_interval: float | None = None,
        stack_depth: float | None = None,
        include_objects_collected_by_major_gc: bool | None = None,
        include_objects_collected_by_minor_gc: bool | None = None
    ):
        super().__init__(
            samplingInterval=sampling_interval,
            stackDepth=stack_depth,
            includeObjectsCollectedByMajorGC=include_objects_collected_by_major_gc,
            includeObjectsCollectedByMinorGC=include_objects_collected_by_minor_gc
        )


class StartTrackingHeapObjectsInput(InputModel):

    trackAllocations: bool | None = None


class StartTrackingHeapObjects(CDPMethod[None]):

    INPUT_VALIDATOR = StartTrackingHeapObjectsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        track_allocations: bool | None = None
    ):
        super().__init__(
            trackAllocations=track_allocations
        )


class StopSamplingOutput(OutputModel):

    profile: HeapProfiler.SamplingHeapProfile


class StopSampling(CDPMethod[StopSamplingOutput]):

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = StopSamplingOutput


class StopTrackingHeapObjectsInput(InputModel):

    reportProgress: bool | None = None
    treatGlobalObjectsAsRoots: bool | None = None  # deprecated
    captureNumericValue: bool | None = None
    exposeInternals: bool | None = None  # experimental


class StopTrackingHeapObjects(CDPMethod[None]):

    INPUT_VALIDATOR = StopTrackingHeapObjectsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        report_progress: bool | None = None,
        treat_global_objects_as_roots: bool | None = None,
        capture_numeric_value: bool | None = None,
        expose_internals: bool | None = None
    ):
        super().__init__(
            reportProgress=report_progress,
            treatGlobalObjectsAsRoots=treat_global_objects_as_roots,
            captureNumericValue=capture_numeric_value,
            exposeInternals=expose_internals
        )


class TakeHeapSnapshotInput(InputModel):

    reportProgress: bool | None = None
    treatGlobalObjectsAsRoots: bool | None = None  # deprecated
    captureNumericValue: bool | None = None
    exposeInternals: bool | None = None  # experimental


class TakeHeapSnapshot(CDPMethod[None]):

    INPUT_VALIDATOR = TakeHeapSnapshotInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        report_progress: bool | None = None,
        treat_global_objects_as_roots: bool | None = None,
        capture_numeric_value: bool | None = None,
        expose_internals: bool | None = None
    ):
        super().__init__(
            reportProgress=report_progress,
            treatGlobalObjectsAsRoots=treat_global_objects_as_roots,
            captureNumericValue=capture_numeric_value,
            exposeInternals=expose_internals
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain emulates different environments for the page.
https://chromedevtools.github.io/devtools-protocol/tot/Emulation/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    DOM,
    Emulation,
    Network,
    Page,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class CanEmulateOutput(OutputModel):

    result: bool


class CanEmulate(CDPMethod[CanEmulateOutput]):  # deprecated
    """ Tells whether emulation is supported. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = CanEmulateOutput


class ClearDeviceMetricsOverride(CDPMethod[None]):
    """ Clears the overridden device metrics. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class ClearGeolocationOverride(CDPMethod[None]):
    """ Clears the overridden Geolocation Position and Error. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class ResetPageScaleFactor(CDPMethod[None]):  # experimental
    """ Requests that page scale factor is reset to initial values. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class SetFocusEmulationEnabledInput(InputModel):

    enabled: bool


class SetFocusEmulationEnabled(CDPMethod[None]):  # experimental
    """ Enables or disables simulating a focused and active page. """

    INPUT_VALIDATOR = SetFocusEmulationEnabledInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool
    ):
        super().__init__(
            enabled=enabled
        )


class SetAutoDarkModeOverrideInput(InputModel):

    enabled: bool | None = None


class SetAutoDarkModeOverride(CDPMethod[None]):  # experimental
    """ Automatically render all web contents using a dark theme. """

    INPUT_VALIDATOR = SetAutoDarkModeOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool | None = None
    ):
        super().__init__(
            enabled=enabled
        )


class SetCPUThrottlingRateInput(InputModel):

    rate: float


class SetCPUThrottlingRate(CDPMethod[None]):
    """ Enables CPU throttling to emulate slow CPUs. """

    INPUT_VALIDATOR = SetCPUThrottlingRateInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        rate: float
    ):
        super().__init__(
            rate=rate
        )


class SetDefaultBackgroundColorOverrideInput(InputModel):

    color: DOM.RGBA | None = None


class SetDefaultBackgroundColorOverride(CDPMethod[None]):
    """ Sets or clears an override of the default background color of the frame. This override is used
    if the content does not specify one. """

    INPUT_VALIDATOR = SetDefaultBackgroundColorOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        color: DOM.RGBA | None = None
    ):
        super().__init__(
            color=color
        )


class SetSafeAreaInsetsOverrideInput(InputModel):

    insets: Emulation.SafeAreaInsets


class SetSafeAreaInsetsOverride(CDPMethod[None]):  # experimental
    """ Overrides the values for env(safe-area-inset-*) and env(safe-area-max-inset-*). Unset values will cause the
    respective variables to be undefined, even if previously overridden. """

    INPUT_VALIDATOR = SetSafeAreaInsetsOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        insets: Emulation.SafeAreaInsets
    ):
        super().__init__(
            insets=insets
        )


class SetDeviceMetricsOverrideInput(InputModel):

    width: int
    height: int
    deviceScaleFactor: float
    mobile: bool
    scale: float | None = None  # experimental
    screenWidth: int | None = None  # experimental
    screenHeight: int | None = None  # experimental
    positionX: int | None = None  # experimental
    positionY: int | None = None  # experimental
    dontSetVisibleSize: bool | None = None  # experimental
    screenOrientation: Emulation.ScreenOrientation | None = None
    viewport: Page.Viewport | None = None  # experimental
    displayFeature: Emulation.DisplayFeature | None = None  # experimental deprecated
    devicePosture: Emulation.DevicePosture | None = None  # experimental deprecated


class SetDeviceMetricsOverride(CDPMethod[None]):
    """ Overrides the values of device screen dimensions (window.screen.width, window.screen.height,
    window.innerWidth, window.innerHeight, and "device-width"/"device-height"-related CSS media
    query results). """

    INPUT_VALIDATOR = SetDeviceMetricsOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        width: int,
        height: int,
        device_scale_factor: float,
        mobile: bool,
        scale: float | None = None,
        screen_width: int | None = None,
        screen_height: int | None = None,
        position_x: int | None = None,
        position_y: int | None = None,
        dont_set_visible_size: bool | None = None,
        screen_orientation: Emulation.ScreenOrientation | None = None,
        viewport: Page.Viewport | None = None,
        display_feature: Emulation.DisplayFeature | None = None,
        device_posture: Emulation.DevicePosture | None = None
    ):
        super().__init__(
            width=width,
            height=height,
            deviceScaleFactor=device_scale_factor,
            mobile=mobile,
            scale=scale,
            screenWidth=screen_width,
            screenHeight=screen_height,
            positionX=position_x,
            positionY=position_y,
            dontSetVisibleSize=dont_set_visible_size,
            screenOrientation=screen_orientation,
            viewport=viewport,
            displayFeature=display_feature,
            devicePosture=device_posture
        )


class SetDevicePostureOverrideInput(InputModel):

    posture: Emulation.DevicePosture


class SetDevicePostureOverride(CDPMethod[None]):  # experimental
    """ Start reporting the given posture value to the Device Posture API.
    This override can also be set in setDeviceMetricsOverride(). """

    INPUT_VALIDATOR = SetDevicePostureOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        posture: Emulation.DevicePosture
    ):
        super().__init__(
            posture=posture
        )


class ClearDevicePostureOverride(CDPMethod[None]):  # experimental
    """ Clears a device posture override set with either setDeviceMetricsOverride()
    or setDevicePostureOverride() and starts using posture information from the
    platform again.
    Does nothing if no override is set. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class SetDisplayFeaturesOverrideInput(InputModel):

    features: list[Emulation.DisplayFeature]


class SetDisplayFeaturesOverride(CDPMethod[None]):  # experimental
    """ Start using the given display features to pupulate the Viewport Segments API.
    This override can also be set in setDeviceMetricsOverride(). """

    INPUT_VALIDATOR = SetDisplayFeaturesOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        features: list[Emulation.DisplayFeature]
    ):
        super().__init__(
            features=features
        )


class ClearDisplayFeaturesOverride(CDPMethod[None]):  # experimental
    """ Clears the display features override set with either setDeviceMetricsOverride()
    or setDisplayFeaturesOverride() and starts using display features from the
    platform again.
    Does nothing if no override is set. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class SetScrollbarsHiddenInput(InputModel):

    hidden: bool


class SetScrollbarsHidden(CDPMethod[None]):  # experimental

    INPUT_VALIDATOR = SetScrollbarsHiddenInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        hidden: bool
    ):
        super().__init__(
            hidden=hidden
        )


class SetDocumentCookieDisabledInput(InputModel):

    disabled: bool


class SetDocumentCookieDisabled(CDPMethod[None]):  # experimental

    INPUT_VALIDATOR = SetDocumentCookieDisabledInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        disabled: bool
    ):
        super().__init__(
            disabled=disabled
        )


class SetEmitTouchEventsForMouseInput(InputModel):

    enabled: bool
    configuration: Literal['mobile', 'desktop'] | None = None


class SetEmitTouchEventsForMouse(CDPMethod[None]):  # experimental

    INPUT_VALIDATOR = SetEmitTouchEventsForMouseInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool,
        configuration: Literal['mobile', 'desktop'] | None = None
    ):
        super().__init__(
            enabled=enabled,
            configuration=configuration
        )


class SetEmulatedMediaInput(InputModel):

    media: str | None = None
    features: list[Emulation.MediaFeature] | None = None


class SetEmulatedMedia(CDPMethod[None]):
    """ Emulates the given media type or media feature for CSS media queries. """

    INPUT_VALIDATOR = SetEmulatedMediaInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        media: str | None = None,
        features: list[Emulation.MediaFeature] | None = None
    ):
        super().__init__(
            media=media,
            features=features
        )


class SetEmulatedVisionDeficiencyInput(InputModel):

    type: Literal['none', 'blurredVision', 'reducedContrast', 'achromatopsia', 'deuteranopia', 'protanopia', 'tritanopia']


class SetEmulatedVisionDeficiency(CDPMethod[None]):
    """ Emulates the given vision deficiency. """

    INPUT_VALIDATOR = SetEmulatedVisionDeficiencyInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        type_: Literal['none', 'blurredVision', 'reducedContrast', 'achromatopsia', 'deuteranopia', 'protanopia', 'tritanopia']
    ):
        super().__init__(
            type=type_
        )


class SetEmulatedOSTextScaleInput(InputModel):

    scale: float | None = None


class SetEmulatedOSTextScale(CDPMethod[None]):
    """ Emulates the given OS text scale. """

    INPUT_VALIDATOR = SetEmulatedOSTextScaleInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        scale: float | None = None
    ):
        super().__init__(
            scale=scale
        )


class SetGeolocationOverrideInput(InputModel):

    latitude: float | None = None
    longitude: float | None = None
    accuracy: float | None = None
    altitude: float | None = None
    altitudeAccuracy: float | None = None
    heading: float | None = None
    speed: float | None = None


class SetGeolocationOverride(CDPMethod[None]):
    """ Overrides the Geolocation Position or Error. Omitting latitude, longitude or
    accuracy emulates position unavailable. """

    INPUT_VALIDATOR = SetGeolocationOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        latitude: float | None = None,
        longitude: float | None = None,
        accuracy: float | None = None,
        altitude: float | None = None,
        altitude_accuracy: float | None = None,
        heading: float | None = None,
        speed: float | None = None
    ):
        super().__init__(
            latitude=latitude,
            longitude=longitude,
            accuracy=accuracy,
            altitude=altitude,
            altitudeAccuracy=altitude_accuracy,
            heading=heading,
            speed=speed
        )


class GetOverriddenSensorInformationInput(InputModel):

    type: Emulation.SensorType


class GetOverriddenSensorInformationOutput(OutputModel):

    requestedSamplingFrequency: float


class GetOverriddenSensorInformation(CDPMethod[GetOverriddenSensorInformationOutput]):  # experimental

    INPUT_VALIDATOR = GetOverriddenSensorInformationInput
    OUTPUT_VALIDATOR = GetOverriddenSensorInformationOutput

    def __init__(
        self,
        *,
        type_: Emulation.SensorType
    ):
        super().__init__(
            type=type_
        )


class SetSensorOverrideEnabledInput(InputModel):

    enabled: bool
    type: Emulation.SensorType
    metadata: Emulation.SensorMetadata | None = None


class SetSensorOverrideEnabled(CDPMethod[None]):  # experimental
    """ Overrides a platform sensor of a given type. If |enabled| is true, calls to
    Sensor.start() will use a virtual sensor as backend rather than fetching
    data from a real hardware sensor. Otherwise, existing virtual
    sensor-backend Sensor objects will fire an error event and new calls to
    Sensor.start() will attempt to use a real sensor instead. """

    INPUT_VALIDATOR = SetSensorOverrideEnabledInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool,
        type_: Emulation.SensorType,
        metadata: Emulation.SensorMetadata | None = None
    ):
        super().__init__(
            enabled=enabled,
            type=type_,
            metadata=metadata
        )


class SetSensorOverrideReadingsInput(InputModel):

    type: Emulation.SensorType
    reading: Emulation.SensorReading


class SetSensorOverrideReadings(CDPMethod[None]):  # experimental
    """ Updates the sensor readings reported by a sensor type previously overridden
    by setSensorOverrideEnabled. """

    INPUT_VALIDATOR = SetSensorOverrideReadingsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        type_: Emulation.SensorType,
        reading: Emulation.SensorReading
    ):
        super().__init__(
            type=type_,
            reading=reading
        )


class SetPressureSourceOverrideEnabledInput(InputModel):

    enabled: bool
    source: Emulation.PressureSource
    metadata: Emulation.PressureMetadata | None = None


class SetPressureSourceOverrideEnabled(CDPMethod[None]):  # experimental
    """ Overrides a pressure source of a given type, as used by the Compute
    Pressure API, so that updates to PressureObserver.observe() are provided
    via setPressureStateOverride instead of being retrieved from
    platform-provided telemetry data. """

    INPUT_VALIDATOR = SetPressureSourceOverrideEnabledInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool,
        source: Emulation.PressureSource,
        metadata: Emulation.PressureMetadata | None = None
    ):
        super().__init__(
            enabled=enabled,
            source=source,
            metadata=metadata
        )


class SetPressureStateOverrideInput(InputModel):

    source: Emulation.PressureSource
    state: Emulation.PressureState


class SetPressureStateOverride(CDPMethod[None]):  # experimental
    """ TODO: OBSOLETE: To remove when setPressureDataOverride is merged.
    Provides a given pressure state that will be processed and eventually be
    delivered to PressureObserver users. |source| must have been previously
    overridden by setPressureSourceOverrideEnabled. """

    INPUT_VALIDATOR = SetPressureStateOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        source: Emulation.PressureSource,
        state: Emulation.PressureState
    ):
        super().__init__(
            source=source,
            state=state
        )


class SetPressureDataOverrideInput(InputModel):

    source: Emulation.PressureSource
    state: Emulation.PressureState
    ownContributionEstimate: float | None = None


class SetPressureDataOverride(CDPMethod[None]):  # experimental
    """ Provides a given pressure data set that will be processed and eventually be
    delivered to PressureObserver users. |source| must have been previously
    overridden by setPressureSourceOverrideEnabled. """

    INPUT_VALIDATOR = SetPressureDataOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        source: Emulation.PressureSource,
        state: Emulation.PressureState,
        own_contribution_estimate: float | None = None
    ):
        super().__init__(
            source=source,
            state=state,
            ownContributionEstimate=own_contribution_estimate
        )


class SetIdleOverrideInput(InputModel):

    isUserActive: bool
    isScreenUnlocked: bool


class SetIdleOverride(CDPMethod[None]):
    """ Overrides the Idle state. """

    INPUT_VALIDATOR = SetIdleOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        is_user_active: bool,
        is_screen_unlocked: bool
    ):
        super().__init__(
            isUserActive=is_user_active,
            isScreenUnlocked=is_screen_unlocked
        )


class ClearIdleOverride(CDPMethod[None]):
    """ Clears Idle state overrides. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class SetNavigatorOverridesInput(InputModel):

    platform: str


class SetNavigatorOverrides(CDPMethod[None]):  # experimental deprecated
    """ Overrides value returned by the javascript navigator object. """

    INPUT_VALIDATOR = SetNavigatorOverridesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        platform: str
    ):
        super().__init__(
            platform=platform
        )


class SetPageScaleFactorInput(InputModel):

    pageScaleFactor: float


class SetPageScaleFactor(CDPMethod[None]):  # experimental
    """ Sets a specified page scale factor. """

    INPUT_VALIDATOR = SetPageScaleFactorInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        page_scale_factor: float
    ):
        super().__init__(
            pageScaleFactor=page_scale_factor
        )


class SetScriptExecutionDisabledInput(InputModel):

    value: bool


class SetScriptExecutionDisabled(CDPMethod[None]):
    """ Switches script execution in the page. """

    INPUT_VALIDATOR = SetScriptExecutionDisabledInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        value: bool
    ):
        super().__init__(
            value=value
        )


class SetTouchEmulationEnabledInput(InputModel):

    enabled: bool
    maxTouchPoints: int | None = None


class SetTouchEmulationEnabled(CDPMethod[None]):
    """ Enables touch on platforms which do not support them. """

    INPUT_VALIDATOR = SetTouchEmulationEnabledInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool,
        max_touch_points: int | None = None
    ):
        super().__init__(
            enabled=enabled,
            maxTouchPoints=max_touch_points
        )


class SetVirtualTimePolicyInput(InputModel):

    policy: Emulation.VirtualTimePolicy
    budget: float | None = None
    maxVirtualTimeTaskStarvationCount: int | None = None
    initialVirtualTime: Network.TimeSinceEpoch | None = None


class SetVirtualTimePolicyOutput(OutputModel):

    virtualTimeTicksBase: float


class SetVirtualTimePolicy(CDPMethod[SetVirtualTimePolicyOutput]):  # experimental
    """ Turns on virtual time for all frames (replacing real-time with a synthetic time source) and sets
    the current virtual time policy.  Note this supersedes any previous time budget. """

    INPUT_VALIDATOR = SetVirtualTimePolicyInput
    OUTPUT_VALIDATOR = SetVirtualTimePolicyOutput

    def __init__(
        self,
        *,
        policy: Emulation.VirtualTimePolicy,
        budget: float | None = None,
        max_virtual_time_task_starvation_count: int | None = None,
        initial_virtual_time: Network.TimeSinceEpoch | None = None
    ):
        super().__init__(
            policy=policy,
            budget=budget,
            maxVirtualTimeTaskStarvationCount=max_virtual_time_task_starvation_count,
            initialVirtualTime=initial_virtual_time
        )


class SetLocaleOverrideInput(InputModel):

    locale: str | None = None


class SetLocaleOverride(CDPMethod[None]):  # experimental
    """ Overrides default host system locale with the specified one. """

    INPUT_VALIDATOR = SetLocaleOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        locale: str | None = None
    ):
        super().__init__(
            locale=locale
        )


class SetTimezoneOverrideInput(InputModel):

    timezoneId: str


class SetTimezoneOverride(CDPMethod[None]):
    """ Overrides default host system timezone with the specified one. """

    INPUT_VALIDATOR = SetTimezoneOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        timezone_id: str
    ):
        super().__init__(
            timezoneId=timezone_id
        )


class SetVisibleSizeInput(InputModel):

    width: int
    height: int


class SetVisibleSize(CDPMethod[None]):  # experimental deprecated
    """ Resizes the frame/viewport of the page. Note that this does not affect the frame's container
    (e.g. browser window). Can be used to produce screenshots of the specified size. Not supported
    on Android. """

    INPUT_VALIDATOR = SetVisibleSizeInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        width: int,
        height: int
    ):
        super().__init__(
            width=width,
            height=height
        )


class SetDisabledImageTypesInput(InputModel):

    imageTypes: list[Emulation.DisabledImageType]


class SetDisabledImageTypes(CDPMethod[None]):  # experimental

    INPUT_VALIDATOR = SetDisabledImageTypesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        image_types: list[Emulation.DisabledImageType]
    ):
        super().__init__(
            imageTypes=image_types
        )


class SetDataSaverOverrideInput(InputModel):

    dataSaverEnabled: bool | None = None


class SetDataSaverOverride(CDPMethod[None]):  # experimental
    """ Override the value of navigator.connection.saveData """

    INPUT_VALIDATOR = SetDataSaverOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        data_saver_enabled: bool | None = None
    ):
        super().__init__(
            dataSaverEnabled=data_saver_enabled
        )


class SetHardwareConcurrencyOverrideInput(InputModel):

    hardwareConcurrency: int


class SetHardwareConcurrencyOverride(CDPMethod[None]):  # experimental

    INPUT_VALIDATOR = SetHardwareConcurrencyOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        hardware_concurrency: int
    ):
        super().__init__(
            hardwareConcurrency=hardware_concurrency
        )


class SetUserAgentOverrideInput(InputModel):

    userAgent: str
    acceptLanguage: str | None = None
    platform: str | None = None
    userAgentMetadata: Emulation.UserAgentMetadata | None = None  # experimental


class SetUserAgentOverride(CDPMethod[None]):
    """ Allows overriding user agent with the given string.
    `userAgentMetadata` must be set for Client Hint headers to be sent. """

    INPUT_VALIDATOR = SetUserAgentOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        user_agent: str,
        accept_language: str | None = None,
        platform: str | None = None,
        user_agent_metadata: Emulation.UserAgentMetadata | None = None
    ):
        super().__init__(
            userAgent=user_agent,
            acceptLanguage=accept_language,
            platform=platform,
            userAgentMetadata=user_agent_metadata
        )


class SetAutomationOverrideInput(InputModel):

    enabled: bool


class SetAutomationOverride(CDPMethod[None]):  # experimental
    """ Allows overriding the automation flag. """

    INPUT_VALIDATOR = SetAutomationOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool
    ):
        super().__init__(
            enabled=enabled
        )


class SetSmallViewportHeightDifferenceOverrideInput(InputModel):

    difference: int


class SetSmallViewportHeightDifferenceOverride(CDPMethod[None]):  # experimental
    """ Allows overriding the difference between the small and large viewport sizes, which determine the
    value of the `svh` and `lvh` unit, respectively. Only supported for top-level frames. """

    INPUT_VALIDATOR = SetSmallViewportHeightDifferenceOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        difference: int
    ):
        super().__init__(
            difference=difference
        )


class GetScreenInfosOutput(OutputModel):

    screenInfos: list[Emulation.ScreenInfo]


class GetScreenInfos(CDPMethod[GetScreenInfosOutput]):  # experimental
    """ Returns device's screen configuration. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetScreenInfosOutput


class AddScreenInput(InputModel):

    left: int
    top: int
    width: int
    height: int
    workAreaInsets: Emulation.WorkAreaInsets | None = None
    devicePixelRatio: float | None = None
    rotation: int | None = None
    colorDepth: int | None = None
    label: str | None = None
    isInternal: bool | None = None


class AddScreenOutput(OutputModel):

    screenInfo: Emulation.ScreenInfo


class AddScreen(CDPMethod[AddScreenOutput]):  # experimental
    """ Add a new screen to the device. Only supported in headless mode. """

    INPUT_VALIDATOR = AddScreenInput
    OUTPUT_VALIDATOR = AddScreenOutput

    def __init__(
        self,
        *,
        left: int,
        top: int,
        width: int,
        height: int,
        work_area_insets: Emulation.WorkAreaInsets | None = None,
        device_pixel_ratio: float | None = None,
        rotation: int | None = None,
        color_depth: int | None = None,
        label: str | None = None,
        is_internal: bool | None = None
    ):
        super().__init__(
            left=left,
            top=top,
            width=width,
            height=height,
            workAreaInsets=work_area_insets,
            devicePixelRatio=device_pixel_ratio,
            rotation=rotation,
            colorDepth=color_depth,
            label=label,
            isInternal=is_internal
        )


class RemoveScreenInput(InputModel):

    screenId: Emulation.ScreenId


class RemoveScreen(CDPMethod[None]):  # experimental
    """ Remove screen from the device. Only supported in headless mode. """

    INPUT_VALIDATOR = RemoveScreenInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        screen_id: Emulation.ScreenId
    ):
        super().__init__(
            screenId=screen_id
        )



from .methods import (
    ForciblyPurgeJavaScriptMemory,
    GetAllTimeSamplingProfile,
    GetBrowserSamplingProfile,
    GetDOMCounters,
    GetDOMCountersForLeakDetection,
    GetSamplingProfile,
    PrepareForLeakDetection,
    SetPressureNotificationsSuppressed,
    SimulatePressureNotification,
    StartSampling,
    StopSampling,
)
from .types import DOMCounter, Module, PressureLevel, SamplingProfile, SamplingProfileNode

__all__ = [
    PressureLevel,
    SamplingProfileNode,
    SamplingProfile,
    Module,
    DOMCounter,
    GetDOMCounters,
    GetDOMCountersForLeakDetection,
    PrepareForLeakDetection,
    ForciblyPurgeJavaScriptMemory,
    SetPressureNotificationsSuppressed,
    SimulatePressureNotification,
    StartSampling,
    StopSampling,
    GetAllTimeSamplingProfile,
    GetBrowserSamplingProfile,
    GetSamplingProfile,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows interacting with the browser to control PWAs.
https://chromedevtools.github.io/devtools-protocol/tot/PWA/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    PWADisplayMode,
    PWAFileHandler,
    PWAFileHandlerAccept,
)

FileHandlerAccept = PWAFileHandlerAccept
FileHandler = PWAFileHandler
DisplayMode = PWADisplayMode



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Network domain allows tracking network activities of the page. It exposes information about http,
file, data and other requests and responses, their headers, bodies, timing, etc.
https://chromedevtools.github.io/devtools-protocol/tot/Network/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    Network,
    Page,
)
from cdpkit.protocol.base import CDPEvent


class DataReceived(CDPEvent):
    """ Fired when data chunk was received over the network. """

    requestId: Network.RequestId
    timestamp: Network.MonotonicTime
    dataLength: int
    encodedDataLength: int
    data: str | None = None  # experimental


class EventSourceMessageReceived(CDPEvent):
    """ Fired when EventSource message is received. """

    requestId: Network.RequestId
    timestamp: Network.MonotonicTime
    eventName: str
    eventId: str
    data: str


class LoadingFailed(CDPEvent):
    """ Fired when HTTP request has failed to load. """

    requestId: Network.RequestId
    timestamp: Network.MonotonicTime
    type: Network.ResourceType
    errorText: str
    canceled: bool | None = None
    blockedReason: Network.BlockedReason | None = None
    corsErrorStatus: Network.CorsErrorStatus | None = None


class LoadingFinished(CDPEvent):
    """ Fired when HTTP request has finished loading. """

    requestId: Network.RequestId
    timestamp: Network.MonotonicTime
    encodedDataLength: float


class RequestIntercepted(CDPEvent):
    """ Details of an intercepted HTTP request, which must be either allowed, blocked, modified or
    mocked.
    Deprecated, use Fetch.requestPaused instead. """

    interceptionId: Network.InterceptionId
    request: Network.Request
    frameId: Page.FrameId
    resourceType: Network.ResourceType
    isNavigationRequest: bool
    isDownload: bool | None = None
    redirectUrl: str | None = None
    authChallenge: Network.AuthChallenge | None = None
    responseErrorReason: Network.ErrorReason | None = None
    responseStatusCode: int | None = None
    responseHeaders: Network.Headers | None = None
    requestId: Network.RequestId | None = None


class RequestServedFromCache(CDPEvent):
    """ Fired if request ended up loading from cache. """

    requestId: Network.RequestId


class RequestWillBeSent(CDPEvent):
    """ Fired when page is about to send HTTP request. """

    requestId: Network.RequestId
    loaderId: Network.LoaderId
    documentURL: str
    request: Network.Request
    timestamp: Network.MonotonicTime
    wallTime: Network.TimeSinceEpoch
    initiator: Network.Initiator
    redirectHasExtraInfo: bool | None = None  # experimental
    redirectResponse: Network.Response | None = None
    type: Network.ResourceType | None = None
    frameId: Page.FrameId | None = None
    hasUserGesture: bool | None = None
    renderBlockingBehavior: Network.RenderBlockingBehavior | None = None  # experimental


class ResourceChangedPriority(CDPEvent):
    """ Fired when resource loading priority is changed """

    requestId: Network.RequestId
    newPriority: Network.ResourcePriority
    timestamp: Network.MonotonicTime


class SignedExchangeReceived(CDPEvent):
    """ Fired when a signed exchange was received over the network """

    requestId: Network.RequestId
    info: Network.SignedExchangeInfo


class ResponseReceived(CDPEvent):
    """ Fired when HTTP response is available. """

    requestId: Network.RequestId
    loaderId: Network.LoaderId
    timestamp: Network.MonotonicTime
    type: Network.ResourceType
    response: Network.Response
    hasExtraInfo: bool | None = None  # experimental
    frameId: Page.FrameId | None = None


class WebSocketClosed(CDPEvent):
    """ Fired when WebSocket is closed. """

    requestId: Network.RequestId
    timestamp: Network.MonotonicTime


class WebSocketCreated(CDPEvent):
    """ Fired upon WebSocket creation. """

    requestId: Network.RequestId
    url: str
    initiator: Network.Initiator | None = None


class WebSocketFrameError(CDPEvent):
    """ Fired when WebSocket message error occurs. """

    requestId: Network.RequestId
    timestamp: Network.MonotonicTime
    errorMessage: str


class WebSocketFrameReceived(CDPEvent):
    """ Fired when WebSocket message is received. """

    requestId: Network.RequestId
    timestamp: Network.MonotonicTime
    response: Network.WebSocketFrame


class WebSocketFrameSent(CDPEvent):
    """ Fired when WebSocket message is sent. """

    requestId: Network.RequestId
    timestamp: Network.MonotonicTime
    response: Network.WebSocketFrame


class WebSocketHandshakeResponseReceived(CDPEvent):
    """ Fired when WebSocket handshake response becomes available. """

    requestId: Network.RequestId
    timestamp: Network.MonotonicTime
    response: Network.WebSocketResponse


class WebSocketWillSendHandshakeRequest(CDPEvent):
    """ Fired when WebSocket is about to initiate handshake. """

    requestId: Network.RequestId
    timestamp: Network.MonotonicTime
    wallTime: Network.TimeSinceEpoch
    request: Network.WebSocketRequest


class WebTransportCreated(CDPEvent):
    """ Fired upon WebTransport creation. """

    transportId: Network.RequestId
    url: str
    timestamp: Network.MonotonicTime
    initiator: Network.Initiator | None = None


class WebTransportConnectionEstablished(CDPEvent):
    """ Fired when WebTransport handshake is finished. """

    transportId: Network.RequestId
    timestamp: Network.MonotonicTime


class WebTransportClosed(CDPEvent):
    """ Fired when WebTransport is disposed. """

    transportId: Network.RequestId
    timestamp: Network.MonotonicTime


class DirectTCPSocketCreated(CDPEvent):
    """ Fired upon direct_socket.TCPSocket creation. """

    identifier: Network.RequestId
    remoteAddr: str
    remotePort: int
    options: Network.DirectTCPSocketOptions
    timestamp: Network.MonotonicTime
    initiator: Network.Initiator | None = None


class DirectTCPSocketOpened(CDPEvent):
    """ Fired when direct_socket.TCPSocket connection is opened. """

    identifier: Network.RequestId
    remoteAddr: str
    remotePort: int
    timestamp: Network.MonotonicTime
    localAddr: str | None = None
    localPort: int | None = None


class DirectTCPSocketAborted(CDPEvent):
    """ Fired when direct_socket.TCPSocket is aborted. """

    identifier: Network.RequestId
    errorMessage: str
    timestamp: Network.MonotonicTime


class DirectTCPSocketClosed(CDPEvent):
    """ Fired when direct_socket.TCPSocket is closed. """

    identifier: Network.RequestId
    timestamp: Network.MonotonicTime


class DirectTCPSocketChunkSent(CDPEvent):
    """ Fired when data is sent to tcp direct socket stream. """

    identifier: Network.RequestId
    data: str
    timestamp: Network.MonotonicTime


class DirectTCPSocketChunkReceived(CDPEvent):
    """ Fired when data is received from tcp direct socket stream. """

    identifier: Network.RequestId
    data: str
    timestamp: Network.MonotonicTime


class DirectUDPSocketJoinedMulticastGroup(CDPEvent):

    identifier: Network.RequestId
    IPAddress: str


class DirectUDPSocketLeftMulticastGroup(CDPEvent):

    identifier: Network.RequestId
    IPAddress: str


class DirectUDPSocketCreated(CDPEvent):
    """ Fired upon direct_socket.UDPSocket creation. """

    identifier: Network.RequestId
    options: Network.DirectUDPSocketOptions
    timestamp: Network.MonotonicTime
    initiator: Network.Initiator | None = None


class DirectUDPSocketOpened(CDPEvent):
    """ Fired when direct_socket.UDPSocket connection is opened. """

    identifier: Network.RequestId
    localAddr: str
    localPort: int
    timestamp: Network.MonotonicTime
    remoteAddr: str | None = None
    remotePort: int | None = None


class DirectUDPSocketAborted(CDPEvent):
    """ Fired when direct_socket.UDPSocket is aborted. """

    identifier: Network.RequestId
    errorMessage: str
    timestamp: Network.MonotonicTime


class DirectUDPSocketClosed(CDPEvent):
    """ Fired when direct_socket.UDPSocket is closed. """

    identifier: Network.RequestId
    timestamp: Network.MonotonicTime


class DirectUDPSocketChunkSent(CDPEvent):
    """ Fired when message is sent to udp direct socket stream. """

    identifier: Network.RequestId
    message: Network.DirectUDPMessage
    timestamp: Network.MonotonicTime


class DirectUDPSocketChunkReceived(CDPEvent):
    """ Fired when message is received from udp direct socket stream. """

    identifier: Network.RequestId
    message: Network.DirectUDPMessage
    timestamp: Network.MonotonicTime


class RequestWillBeSentExtraInfo(CDPEvent):
    """ Fired when additional information about a requestWillBeSent event is available from the
    network stack. Not every requestWillBeSent event will have an additional
    requestWillBeSentExtraInfo fired for it, and there is no guarantee whether requestWillBeSent
    or requestWillBeSentExtraInfo will be fired first for the same request. """

    requestId: Network.RequestId
    associatedCookies: list[Network.AssociatedCookie]
    headers: Network.Headers
    connectTiming: Network.ConnectTiming | None = None  # experimental
    clientSecurityState: Network.ClientSecurityState | None = None
    siteHasCookieInOtherPartition: bool | None = None
    appliedNetworkConditionsId: str | None = None


class ResponseReceivedExtraInfo(CDPEvent):
    """ Fired when additional information about a responseReceived event is available from the network
    stack. Not every responseReceived event will have an additional responseReceivedExtraInfo for
    it, and responseReceivedExtraInfo may be fired before or after responseReceived. """

    requestId: Network.RequestId
    blockedCookies: list[Network.BlockedSetCookieWithReason]
    headers: Network.Headers
    resourceIPAddressSpace: Network.IPAddressSpace
    statusCode: int
    headersText: str | None = None
    cookiePartitionKey: Network.CookiePartitionKey | None = None  # experimental
    cookiePartitionKeyOpaque: bool | None = None
    exemptedCookies: list[Network.ExemptedSetCookieWithReason] | None = None


class ResponseReceivedEarlyHints(CDPEvent):
    """ Fired when 103 Early Hints headers is received in addition to the common response.
    Not every responseReceived event will have an responseReceivedEarlyHints fired.
    Only one responseReceivedEarlyHints may be fired for eached responseReceived event. """

    requestId: Network.RequestId
    headers: Network.Headers


class TrustTokenOperationDone(CDPEvent):
    """ Fired exactly once for each Trust Token operation. Depending on
    the type of the operation and whether the operation succeeded or
    failed, the event is fired before the corresponding request was sent
    or after the response was received. """

    status: Literal['Ok', 'InvalidArgument', 'MissingIssuerKeys', 'FailedPrecondition', 'ResourceExhausted', 'AlreadyExists', 'ResourceLimited', 'Unauthorized', 'BadResponse', 'InternalError', 'UnknownError', 'FulfilledLocally', 'SiteIssuerLimit']
    type: Network.TrustTokenOperationType
    requestId: Network.RequestId
    topLevelOrigin: str | None = None
    issuerOrigin: str | None = None
    issuedTokenCount: int | None = None


class PolicyUpdated(CDPEvent):
    """ Fired once security policy has been updated. """

    ...


class ReportingApiReportAdded(CDPEvent):
    """ Is sent whenever a new report is added.
    And after 'enableReportingApi' for all existing reports. """

    report: Network.ReportingApiReport


class ReportingApiReportUpdated(CDPEvent):

    report: Network.ReportingApiReport


class ReportingApiEndpointsChangedForOrigin(CDPEvent):

    origin: str
    endpoints: list[Network.ReportingApiEndpoint]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

The SystemInfo domain defines methods and events for querying low-level system information.
https://chromedevtools.github.io/devtools-protocol/tot/SystemInfo/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    SystemInfoGPUDevice,
    SystemInfoGPUInfo,
    SystemInfoImageType,
    SystemInfoProcessInfo,
    SystemInfoSize,
    SystemInfoSubsamplingFormat,
    SystemInfoVideoDecodeAcceleratorCapability,
    SystemInfoVideoEncodeAcceleratorCapability,
)

GPUDevice = SystemInfoGPUDevice
Size = SystemInfoSize
VideoDecodeAcceleratorCapability = SystemInfoVideoDecodeAcceleratorCapability
VideoEncodeAcceleratorCapability = SystemInfoVideoEncodeAcceleratorCapability
SubsamplingFormat = SystemInfoSubsamplingFormat
ImageType = SystemInfoImageType
GPUInfo = SystemInfoGPUInfo
ProcessInfo = SystemInfoProcessInfo



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol.base import CDPEvent


class AddHeapSnapshotChunk(CDPEvent):

    chunk: str


class HeapStatsUpdate(CDPEvent):
    """ If heap objects tracking has been started then backend may send update for one or more fragments """

    statsUpdate: list[int]


class LastSeenObjectId(CDPEvent):
    """ If heap objects tracking has been started then backend regularly sends a current value for last
    seen object id and corresponding timestamp. If the were changes in the heap since last event
    then one or more heapStatsUpdate events will be sent before a new lastSeenObjectId event. """

    lastSeenObjectId: int
    timestamp: float


class ReportHeapSnapshotProgress(CDPEvent):

    done: int
    total: int
    finished: bool | None = None


class ResetProfiles(CDPEvent):

    ...



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows interacting with the browser to control PWAs.
https://chromedevtools.github.io/devtools-protocol/tot/PWA/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    PWA,
    Target,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class GetOsAppStateInput(InputModel):

    manifestId: str


class GetOsAppStateOutput(OutputModel):

    badgeCount: int
    fileHandlers: list[PWA.FileHandler]


class GetOsAppState(CDPMethod[GetOsAppStateOutput]):
    """ Returns the following OS state for the given manifest id. """

    INPUT_VALIDATOR = GetOsAppStateInput
    OUTPUT_VALIDATOR = GetOsAppStateOutput

    def __init__(
        self,
        *,
        manifest_id: str
    ):
        super().__init__(
            manifestId=manifest_id
        )


class InstallInput(InputModel):

    manifestId: str
    installUrlOrBundleUrl: str | None = None


class Install(CDPMethod[None]):
    """ Installs the given manifest identity, optionally using the given installUrlOrBundleUrl

    IWA-specific install description:
    manifestId corresponds to isolated-app:// + web_package::SignedWebBundleId

    File installation mode:
    The installUrlOrBundleUrl can be either file:// or http(s):// pointing
    to a signed web bundle (.swbn). In this case SignedWebBundleId must correspond to
    The .swbn file's signing key.

    Dev proxy installation mode:
    installUrlOrBundleUrl must be http(s):// that serves dev mode IWA.
    web_package::SignedWebBundleId must be of type dev proxy.

    The advantage of dev proxy mode is that all changes to IWA
    automatically will be reflected in the running app without
    reinstallation.

    To generate bundle id for proxy mode:
    1. Generate 32 random bytes.
    2. Add a specific suffix at the end following the documentation
       https://github.com/WICG/isolated-web-apps/blob/main/Scheme.md#suffix
    3. Encode the entire sequence using Base32 without padding.

    If Chrome is not in IWA dev
    mode, the installation will fail, regardless of the state of the allowlist. """

    INPUT_VALIDATOR = InstallInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        manifest_id: str,
        install_url_or_bundle_url: str | None = None
    ):
        super().__init__(
            manifestId=manifest_id,
            installUrlOrBundleUrl=install_url_or_bundle_url
        )


class UninstallInput(InputModel):

    manifestId: str


class Uninstall(CDPMethod[None]):
    """ Uninstalls the given manifest_id and closes any opened app windows. """

    INPUT_VALIDATOR = UninstallInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        manifest_id: str
    ):
        super().__init__(
            manifestId=manifest_id
        )


class LaunchInput(InputModel):

    manifestId: str
    url: str | None = None


class LaunchOutput(OutputModel):

    targetId: Target.TargetID


class Launch(CDPMethod[LaunchOutput]):
    """ Launches the installed web app, or an url in the same web app instead of the
    default start url if it is provided. Returns a page Target.TargetID which
    can be used to attach to via Target.attachToTarget or similar APIs. """

    INPUT_VALIDATOR = LaunchInput
    OUTPUT_VALIDATOR = LaunchOutput

    def __init__(
        self,
        *,
        manifest_id: str,
        url: str | None = None
    ):
        super().__init__(
            manifestId=manifest_id,
            url=url
        )


class LaunchFilesInAppInput(InputModel):

    manifestId: str
    files: list[str]


class LaunchFilesInAppOutput(OutputModel):

    targetIds: list[Target.TargetID]


class LaunchFilesInApp(CDPMethod[LaunchFilesInAppOutput]):
    """ Opens one or more local files from an installed web app identified by its
    manifestId. The web app needs to have file handlers registered to process
    the files. The API returns one or more page Target.TargetIDs which can be
    used to attach to via Target.attachToTarget or similar APIs.
    If some files in the parameters cannot be handled by the web app, they will
    be ignored. If none of the files can be handled, this API returns an error.
    If no files are provided as the parameter, this API also returns an error.

    According to the definition of the file handlers in the manifest file, one
    Target.TargetID may represent a page handling one or more files. The order
    of the returned Target.TargetIDs is not guaranteed.

    TODO(crbug.com/339454034): Check the existences of the input files. """

    INPUT_VALIDATOR = LaunchFilesInAppInput
    OUTPUT_VALIDATOR = LaunchFilesInAppOutput

    def __init__(
        self,
        *,
        manifest_id: str,
        files: list[str]
    ):
        super().__init__(
            manifestId=manifest_id,
            files=files
        )


class OpenCurrentPageInAppInput(InputModel):

    manifestId: str


class OpenCurrentPageInApp(CDPMethod[None]):
    """ Opens the current page in its web app identified by the manifest id, needs
    to be called on a page target. This function returns immediately without
    waiting for the app to finish loading. """

    INPUT_VALIDATOR = OpenCurrentPageInAppInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        manifest_id: str
    ):
        super().__init__(
            manifestId=manifest_id
        )


class ChangeAppUserSettingsInput(InputModel):

    manifestId: str
    linkCapturing: bool | None = None
    displayMode: PWA.DisplayMode | None = None


class ChangeAppUserSettings(CDPMethod[None]):
    """ Changes user settings of the web app identified by its manifestId. If the
    app was not installed, this command returns an error. Unset parameters will
    be ignored; unrecognized values will cause an error.

    Unlike the ones defined in the manifest files of the web apps, these
    settings are provided by the browser and controlled by the users, they
    impact the way the browser handling the web apps.

    See the comment of each parameter. """

    INPUT_VALIDATOR = ChangeAppUserSettingsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        manifest_id: str,
        link_capturing: bool | None = None,
        display_mode: PWA.DisplayMode | None = None
    ):
        super().__init__(
            manifestId=manifest_id,
            linkCapturing=link_capturing,
            displayMode=display_mode
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Defines commands and events for browser extensions.
https://chromedevtools.github.io/devtools-protocol/tot/Extensions/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    ExtensionsStorageArea,
)

StorageArea = ExtensionsStorageArea



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/DeviceOrientation/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol.base import CDPMethod, InputModel


class ClearDeviceOrientationOverride(CDPMethod[None]):
    """ Clears the overridden Device Orientation. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class SetDeviceOrientationOverrideInput(InputModel):

    alpha: float
    beta: float
    gamma: float


class SetDeviceOrientationOverride(CDPMethod[None]):
    """ Overrides the Device Orientation. """

    INPUT_VALIDATOR = SetDeviceOrientationOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        alpha: float,
        beta: float,
        gamma: float
    ):
        super().__init__(
            alpha=alpha,
            beta=beta,
            gamma=gamma
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Supports additional targets discovery and allows to attach to them.
https://chromedevtools.github.io/devtools-protocol/tot/Target/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    TargetFilterEntry,
    TargetRemoteLocation,
    TargetSessionID,
    TargetTargetFilter,
    TargetTargetID,
    TargetTargetInfo,
    TargetWindowState,
)

TargetID = TargetTargetID
SessionID = TargetSessionID
TargetInfo = TargetTargetInfo
FilterEntry = TargetFilterEntry
TargetFilter = TargetTargetFilter
RemoteLocation = TargetRemoteLocation
WindowState = TargetWindowState



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows configuring virtual authenticators to test the WebAuthn
API.
https://chromedevtools.github.io/devtools-protocol/tot/WebAuthn/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    WebAuthnAuthenticatorId,
    WebAuthnAuthenticatorProtocol,
    WebAuthnAuthenticatorTransport,
    WebAuthnCredential,
    WebAuthnCtap2Version,
    WebAuthnVirtualAuthenticatorOptions,
)

AuthenticatorId = WebAuthnAuthenticatorId
AuthenticatorProtocol = WebAuthnAuthenticatorProtocol
Ctap2Version = WebAuthnCtap2Version
AuthenticatorTransport = WebAuthnAuthenticatorTransport
VirtualAuthenticatorOptions = WebAuthnVirtualAuthenticatorOptions
Credential = WebAuthnCredential



from .events import AddressFormFilled
from .methods import Disable, Enable, SetAddresses, Trigger
from .types import Address, AddressField, AddressFields, AddressUI, CreditCard, FilledField, FillingStrategy

__all__ = [
    CreditCard,
    AddressField,
    AddressFields,
    Address,
    AddressUI,
    FillingStrategy,
    FilledField,
    AddressFormFilled,
    Trigger,
    SetAddresses,
    Disable,
    Enable,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Actions and events related to the inspected page belong to the page domain.
https://chromedevtools.github.io/devtools-protocol/tot/Page/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    PageAdFrameExplanation,
    PageAdFrameStatus,
    PageAdFrameType,
    PageAdScriptAncestry,
    PageAdScriptId,
    PageAppManifestError,
    PageAppManifestParsedProperties,
    PageBackForwardCacheBlockingDetails,
    PageBackForwardCacheNotRestoredExplanation,
    PageBackForwardCacheNotRestoredExplanationTree,
    PageBackForwardCacheNotRestoredReason,
    PageBackForwardCacheNotRestoredReasonType,
    PageClientNavigationDisposition,
    PageClientNavigationReason,
    PageCompilationCacheParams,
    PageCrossOriginIsolatedContextType,
    PageDialogType,
    PageFileFilter,
    PageFileHandler,
    PageFontFamilies,
    PageFontSizes,
    PageFrame,
    PageFrameId,
    PageFrameResource,
    PageFrameResourceTree,
    PageFrameTree,
    PageGatedAPIFeatures,
    PageImageResource,
    PageInstallabilityError,
    PageInstallabilityErrorArgument,
    PageLaunchHandler,
    PageLayoutViewport,
    PageNavigationEntry,
    PageNavigationType,
    PageOriginTrial,
    PageOriginTrialStatus,
    PageOriginTrialToken,
    PageOriginTrialTokenStatus,
    PageOriginTrialTokenWithStatus,
    PageOriginTrialUsageRestriction,
    PagePermissionsPolicyBlockLocator,
    PagePermissionsPolicyBlockReason,
    PagePermissionsPolicyFeature,
    PagePermissionsPolicyFeatureState,
    PageProtocolHandler,
    PageReferrerPolicy,
    PageRelatedApplication,
    PageScopeExtension,
    PageScreencastFrameMetadata,
    PageScreenshot,
    PageScriptFontFamilies,
    PageScriptIdentifier,
    PageSecureContextType,
    PageSecurityOriginDetails,
    PageShareTarget,
    PageShortcut,
    PageTransitionType,
    PageViewport,
    PageVisualViewport,
    PageWebAppManifest,
)

FrameId = PageFrameId
AdFrameType = PageAdFrameType
AdFrameExplanation = PageAdFrameExplanation
AdFrameStatus = PageAdFrameStatus
AdScriptId = PageAdScriptId
AdScriptAncestry = PageAdScriptAncestry
SecureContextType = PageSecureContextType
CrossOriginIsolatedContextType = PageCrossOriginIsolatedContextType
GatedAPIFeatures = PageGatedAPIFeatures
PermissionsPolicyFeature = PagePermissionsPolicyFeature
PermissionsPolicyBlockReason = PagePermissionsPolicyBlockReason
PermissionsPolicyBlockLocator = PagePermissionsPolicyBlockLocator
PermissionsPolicyFeatureState = PagePermissionsPolicyFeatureState
OriginTrialTokenStatus = PageOriginTrialTokenStatus
OriginTrialStatus = PageOriginTrialStatus
OriginTrialUsageRestriction = PageOriginTrialUsageRestriction
OriginTrialToken = PageOriginTrialToken
OriginTrialTokenWithStatus = PageOriginTrialTokenWithStatus
OriginTrial = PageOriginTrial
SecurityOriginDetails = PageSecurityOriginDetails
Frame = PageFrame
FrameResource = PageFrameResource
FrameResourceTree = PageFrameResourceTree
FrameTree = PageFrameTree
ScriptIdentifier = PageScriptIdentifier
TransitionType = PageTransitionType
NavigationEntry = PageNavigationEntry
ScreencastFrameMetadata = PageScreencastFrameMetadata
DialogType = PageDialogType
AppManifestError = PageAppManifestError
AppManifestParsedProperties = PageAppManifestParsedProperties
LayoutViewport = PageLayoutViewport
VisualViewport = PageVisualViewport
Viewport = PageViewport
FontFamilies = PageFontFamilies
ScriptFontFamilies = PageScriptFontFamilies
FontSizes = PageFontSizes
ClientNavigationReason = PageClientNavigationReason
ClientNavigationDisposition = PageClientNavigationDisposition
InstallabilityErrorArgument = PageInstallabilityErrorArgument
InstallabilityError = PageInstallabilityError
ReferrerPolicy = PageReferrerPolicy
CompilationCacheParams = PageCompilationCacheParams
FileFilter = PageFileFilter
FileHandler = PageFileHandler
ImageResource = PageImageResource
LaunchHandler = PageLaunchHandler
ProtocolHandler = PageProtocolHandler
RelatedApplication = PageRelatedApplication
ScopeExtension = PageScopeExtension
Screenshot = PageScreenshot
ShareTarget = PageShareTarget
Shortcut = PageShortcut
WebAppManifest = PageWebAppManifest
NavigationType = PageNavigationType
BackForwardCacheNotRestoredReason = PageBackForwardCacheNotRestoredReason
BackForwardCacheNotRestoredReasonType = PageBackForwardCacheNotRestoredReasonType
BackForwardCacheBlockingDetails = PageBackForwardCacheBlockingDetails
BackForwardCacheNotRestoredExplanation = PageBackForwardCacheNotRestoredExplanation
BackForwardCacheNotRestoredExplanationTree = PageBackForwardCacheNotRestoredExplanationTree



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Actions and events related to the inspected page belong to the page domain.
https://chromedevtools.github.io/devtools-protocol/tot/Page/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    DOM,
    IO,
    Debugger,
    Emulation,
    Network,
    Page,
    Runtime,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class AddScriptToEvaluateOnLoadInput(InputModel):

    scriptSource: str


class AddScriptToEvaluateOnLoadOutput(OutputModel):

    identifier: Page.ScriptIdentifier


class AddScriptToEvaluateOnLoad(CDPMethod[AddScriptToEvaluateOnLoadOutput]):  # experimental deprecated
    """ Deprecated, please use addScriptToEvaluateOnNewDocument instead. """

    INPUT_VALIDATOR = AddScriptToEvaluateOnLoadInput
    OUTPUT_VALIDATOR = AddScriptToEvaluateOnLoadOutput

    def __init__(
        self,
        *,
        script_source: str
    ):
        super().__init__(
            scriptSource=script_source
        )


class AddScriptToEvaluateOnNewDocumentInput(InputModel):

    source: str
    worldName: str | None = None  # experimental
    includeCommandLineAPI: bool | None = None  # experimental
    runImmediately: bool | None = None  # experimental


class AddScriptToEvaluateOnNewDocumentOutput(OutputModel):

    identifier: Page.ScriptIdentifier


class AddScriptToEvaluateOnNewDocument(CDPMethod[AddScriptToEvaluateOnNewDocumentOutput]):
    """ Evaluates given script in every frame upon creation (before loading frame's scripts). """

    INPUT_VALIDATOR = AddScriptToEvaluateOnNewDocumentInput
    OUTPUT_VALIDATOR = AddScriptToEvaluateOnNewDocumentOutput

    def __init__(
        self,
        *,
        source: str,
        world_name: str | None = None,
        include_command_line_api: bool | None = None,
        run_immediately: bool | None = None
    ):
        super().__init__(
            source=source,
            worldName=world_name,
            includeCommandLineAPI=include_command_line_api,
            runImmediately=run_immediately
        )


class BringToFront(CDPMethod[None]):
    """ Brings page to front (activates tab). """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class CaptureScreenshotInput(InputModel):

    format: Literal['jpeg', 'png', 'webp'] | None = None
    quality: int | None = None
    clip: Page.Viewport | None = None
    fromSurface: bool | None = None  # experimental
    captureBeyondViewport: bool | None = None  # experimental
    optimizeForSpeed: bool | None = None  # experimental


class CaptureScreenshotOutput(OutputModel):

    data: str


class CaptureScreenshot(CDPMethod[CaptureScreenshotOutput]):
    """ Capture page screenshot. """

    INPUT_VALIDATOR = CaptureScreenshotInput
    OUTPUT_VALIDATOR = CaptureScreenshotOutput

    def __init__(
        self,
        *,
        format_: Literal['jpeg', 'png', 'webp'] | None = None,
        quality: int | None = None,
        clip: Page.Viewport | None = None,
        from_surface: bool | None = None,
        capture_beyond_viewport: bool | None = None,
        optimize_for_speed: bool | None = None
    ):
        super().__init__(
            format=format_,
            quality=quality,
            clip=clip,
            fromSurface=from_surface,
            captureBeyondViewport=capture_beyond_viewport,
            optimizeForSpeed=optimize_for_speed
        )


class CaptureSnapshotInput(InputModel):

    format: Literal['mhtml'] | None = None


class CaptureSnapshotOutput(OutputModel):

    data: str


class CaptureSnapshot(CDPMethod[CaptureSnapshotOutput]):  # experimental
    """ Returns a snapshot of the page as a string. For MHTML format, the serialization includes
    iframes, shadow DOM, external resources, and element-inline styles. """

    INPUT_VALIDATOR = CaptureSnapshotInput
    OUTPUT_VALIDATOR = CaptureSnapshotOutput

    def __init__(
        self,
        *,
        format_: Literal['mhtml'] | None = None
    ):
        super().__init__(
            format=format_
        )


class ClearDeviceMetricsOverride(CDPMethod[None]):  # experimental deprecated
    """ Clears the overridden device metrics. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class ClearDeviceOrientationOverride(CDPMethod[None]):  # experimental deprecated
    """ Clears the overridden Device Orientation. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class ClearGeolocationOverride(CDPMethod[None]):  # deprecated
    """ Clears the overridden Geolocation Position and Error. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class CreateIsolatedWorldInput(InputModel):

    frameId: Page.FrameId
    worldName: str | None = None
    grantUniveralAccess: bool | None = None


class CreateIsolatedWorldOutput(OutputModel):

    executionContextId: Runtime.ExecutionContextId


class CreateIsolatedWorld(CDPMethod[CreateIsolatedWorldOutput]):
    """ Creates an isolated world for the given frame. """

    INPUT_VALIDATOR = CreateIsolatedWorldInput
    OUTPUT_VALIDATOR = CreateIsolatedWorldOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId,
        world_name: str | None = None,
        grant_univeral_access: bool | None = None
    ):
        super().__init__(
            frameId=frame_id,
            worldName=world_name,
            grantUniveralAccess=grant_univeral_access
        )


class DeleteCookieInput(InputModel):

    cookieName: str
    url: str


class DeleteCookie(CDPMethod[None]):  # experimental deprecated
    """ Deletes browser cookie with given name, domain and path. """

    INPUT_VALIDATOR = DeleteCookieInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        cookie_name: str,
        url: str
    ):
        super().__init__(
            cookieName=cookie_name,
            url=url
        )


class Disable(CDPMethod[None]):
    """ Disables page domain notifications. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class EnableInput(InputModel):

    enableFileChooserOpenedEvent: bool | None = None  # experimental


class Enable(CDPMethod[None]):
    """ Enables page domain notifications. """

    INPUT_VALIDATOR = EnableInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enable_file_chooser_opened_event: bool | None = None
    ):
        super().__init__(
            enableFileChooserOpenedEvent=enable_file_chooser_opened_event
        )


class GetAppManifestInput(InputModel):

    manifestId: str | None = None


class GetAppManifestOutput(OutputModel):

    url: str
    errors: list[Page.AppManifestError]
    data: str | None = None
    parsed: Page.AppManifestParsedProperties | None = None  # experimental deprecated
    manifest: Page.WebAppManifest | None = None  # experimental


class GetAppManifest(CDPMethod[GetAppManifestOutput]):
    """ Gets the processed manifest for this current document.
      This API always waits for the manifest to be loaded.
      If manifestId is provided, and it does not match the manifest of the
        current document, this API errors out.
      If there is not a loaded page, this API errors out immediately. """

    INPUT_VALIDATOR = GetAppManifestInput
    OUTPUT_VALIDATOR = GetAppManifestOutput

    def __init__(
        self,
        *,
        manifest_id: str | None = None
    ):
        super().__init__(
            manifestId=manifest_id
        )


class GetInstallabilityErrorsOutput(OutputModel):

    installabilityErrors: list[Page.InstallabilityError]


class GetInstallabilityErrors(CDPMethod[GetInstallabilityErrorsOutput]):  # experimental

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetInstallabilityErrorsOutput


class GetManifestIconsOutput(OutputModel):

    primaryIcon: str | None = None


class GetManifestIcons(CDPMethod[GetManifestIconsOutput]):  # experimental deprecated
    """ Deprecated because it's not guaranteed that the returned icon is in fact the one used for PWA installation. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetManifestIconsOutput


class GetAppIdOutput(OutputModel):

    appId: str | None = None
    recommendedId: str | None = None


class GetAppId(CDPMethod[GetAppIdOutput]):  # experimental
    """ Returns the unique (PWA) app id.
    Only returns values if the feature flag 'WebAppEnableManifestId' is enabled """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetAppIdOutput


class GetAdScriptAncestryInput(InputModel):

    frameId: Page.FrameId


class GetAdScriptAncestryOutput(OutputModel):

    adScriptAncestry: Page.AdScriptAncestry | None = None


class GetAdScriptAncestry(CDPMethod[GetAdScriptAncestryOutput]):  # experimental

    INPUT_VALIDATOR = GetAdScriptAncestryInput
    OUTPUT_VALIDATOR = GetAdScriptAncestryOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId
    ):
        super().__init__(
            frameId=frame_id
        )


class GetFrameTreeOutput(OutputModel):

    frameTree: Page.FrameTree


class GetFrameTree(CDPMethod[GetFrameTreeOutput]):
    """ Returns present frame tree structure. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetFrameTreeOutput


class GetLayoutMetricsOutput(OutputModel):

    layoutViewport: Page.LayoutViewport  # deprecated
    visualViewport: Page.VisualViewport  # deprecated
    contentSize: DOM.Rect  # deprecated
    cssLayoutViewport: Page.LayoutViewport
    cssVisualViewport: Page.VisualViewport
    cssContentSize: DOM.Rect


class GetLayoutMetrics(CDPMethod[GetLayoutMetricsOutput]):
    """ Returns metrics relating to the layouting of the page, such as viewport bounds/scale. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetLayoutMetricsOutput


class GetNavigationHistoryOutput(OutputModel):

    currentIndex: int
    entries: list[Page.NavigationEntry]


class GetNavigationHistory(CDPMethod[GetNavigationHistoryOutput]):
    """ Returns navigation history for the current page. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetNavigationHistoryOutput


class ResetNavigationHistory(CDPMethod[None]):
    """ Resets navigation history for the current page. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class GetResourceContentInput(InputModel):

    frameId: Page.FrameId
    url: str


class GetResourceContentOutput(OutputModel):

    content: str
    base64Encoded: bool


class GetResourceContent(CDPMethod[GetResourceContentOutput]):  # experimental
    """ Returns content of the given resource. """

    INPUT_VALIDATOR = GetResourceContentInput
    OUTPUT_VALIDATOR = GetResourceContentOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId,
        url: str
    ):
        super().__init__(
            frameId=frame_id,
            url=url
        )


class GetResourceTreeOutput(OutputModel):

    frameTree: Page.FrameResourceTree


class GetResourceTree(CDPMethod[GetResourceTreeOutput]):  # experimental
    """ Returns present frame / resource tree structure. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetResourceTreeOutput


class HandleJavaScriptDialogInput(InputModel):

    accept: bool
    promptText: str | None = None


class HandleJavaScriptDialog(CDPMethod[None]):
    """ Accepts or dismisses a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload). """

    INPUT_VALIDATOR = HandleJavaScriptDialogInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        accept: bool,
        prompt_text: str | None = None
    ):
        super().__init__(
            accept=accept,
            promptText=prompt_text
        )


class NavigateInput(InputModel):

    url: str
    referrer: str | None = None
    transitionType: Page.TransitionType | None = None
    frameId: Page.FrameId | None = None
    referrerPolicy: Page.ReferrerPolicy | None = None  # experimental


class NavigateOutput(OutputModel):

    frameId: Page.FrameId
    loaderId: Network.LoaderId | None = None
    errorText: str | None = None
    isDownload: bool | None = None  # experimental


class Navigate(CDPMethod[NavigateOutput]):
    """ Navigates current page to the given URL. """

    INPUT_VALIDATOR = NavigateInput
    OUTPUT_VALIDATOR = NavigateOutput

    def __init__(
        self,
        *,
        url: str,
        referrer: str | None = None,
        transition_type: Page.TransitionType | None = None,
        frame_id: Page.FrameId | None = None,
        referrer_policy: Page.ReferrerPolicy | None = None
    ):
        super().__init__(
            url=url,
            referrer=referrer,
            transitionType=transition_type,
            frameId=frame_id,
            referrerPolicy=referrer_policy
        )


class NavigateToHistoryEntryInput(InputModel):

    entryId: int


class NavigateToHistoryEntry(CDPMethod[None]):
    """ Navigates current page to the given history entry. """

    INPUT_VALIDATOR = NavigateToHistoryEntryInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        entry_id: int
    ):
        super().__init__(
            entryId=entry_id
        )


class PrintToPDFInput(InputModel):

    landscape: bool | None = None
    displayHeaderFooter: bool | None = None
    printBackground: bool | None = None
    scale: float | None = None
    paperWidth: float | None = None
    paperHeight: float | None = None
    marginTop: float | None = None
    marginBottom: float | None = None
    marginLeft: float | None = None
    marginRight: float | None = None
    pageRanges: str | None = None
    headerTemplate: str | None = None
    footerTemplate: str | None = None
    preferCSSPageSize: bool | None = None
    transferMode: Literal['ReturnAsBase64', 'ReturnAsStream'] | None = None  # experimental
    generateTaggedPDF: bool | None = None  # experimental
    generateDocumentOutline: bool | None = None  # experimental


class PrintToPDFOutput(OutputModel):

    data: str
    stream: IO.StreamHandle | None = None  # experimental


class PrintToPDF(CDPMethod[PrintToPDFOutput]):
    """ Print page as PDF. """

    INPUT_VALIDATOR = PrintToPDFInput
    OUTPUT_VALIDATOR = PrintToPDFOutput

    def __init__(
        self,
        *,
        landscape: bool | None = None,
        display_header_footer: bool | None = None,
        print_background: bool | None = None,
        scale: float | None = None,
        paper_width: float | None = None,
        paper_height: float | None = None,
        margin_top: float | None = None,
        margin_bottom: float | None = None,
        margin_left: float | None = None,
        margin_right: float | None = None,
        page_ranges: str | None = None,
        header_template: str | None = None,
        footer_template: str | None = None,
        prefer_css_page_size: bool | None = None,
        transfer_mode: Literal['ReturnAsBase64', 'ReturnAsStream'] | None = None,
        generate_tagged_pdf: bool | None = None,
        generate_document_outline: bool | None = None
    ):
        super().__init__(
            landscape=landscape,
            displayHeaderFooter=display_header_footer,
            printBackground=print_background,
            scale=scale,
            paperWidth=paper_width,
            paperHeight=paper_height,
            marginTop=margin_top,
            marginBottom=margin_bottom,
            marginLeft=margin_left,
            marginRight=margin_right,
            pageRanges=page_ranges,
            headerTemplate=header_template,
            footerTemplate=footer_template,
            preferCSSPageSize=prefer_css_page_size,
            transferMode=transfer_mode,
            generateTaggedPDF=generate_tagged_pdf,
            generateDocumentOutline=generate_document_outline
        )


class ReloadInput(InputModel):

    ignoreCache: bool | None = None
    scriptToEvaluateOnLoad: str | None = None
    loaderId: Network.LoaderId | None = None  # experimental


class Reload(CDPMethod[None]):
    """ Reloads given page optionally ignoring the cache. """

    INPUT_VALIDATOR = ReloadInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        ignore_cache: bool | None = None,
        script_to_evaluate_on_load: str | None = None,
        loader_id: Network.LoaderId | None = None
    ):
        super().__init__(
            ignoreCache=ignore_cache,
            scriptToEvaluateOnLoad=script_to_evaluate_on_load,
            loaderId=loader_id
        )


class RemoveScriptToEvaluateOnLoadInput(InputModel):

    identifier: Page.ScriptIdentifier


class RemoveScriptToEvaluateOnLoad(CDPMethod[None]):  # experimental deprecated
    """ Deprecated, please use removeScriptToEvaluateOnNewDocument instead. """

    INPUT_VALIDATOR = RemoveScriptToEvaluateOnLoadInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        identifier: Page.ScriptIdentifier
    ):
        super().__init__(
            identifier=identifier
        )


class RemoveScriptToEvaluateOnNewDocumentInput(InputModel):

    identifier: Page.ScriptIdentifier


class RemoveScriptToEvaluateOnNewDocument(CDPMethod[None]):
    """ Removes given script from the list. """

    INPUT_VALIDATOR = RemoveScriptToEvaluateOnNewDocumentInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        identifier: Page.ScriptIdentifier
    ):
        super().__init__(
            identifier=identifier
        )


class ScreencastFrameAckInput(InputModel):

    sessionId: int


class ScreencastFrameAck(CDPMethod[None]):  # experimental
    """ Acknowledges that a screencast frame has been received by the frontend. """

    INPUT_VALIDATOR = ScreencastFrameAckInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        session_id: int
    ):
        super().__init__(
            sessionId=session_id
        )


class SearchInResourceInput(InputModel):

    frameId: Page.FrameId
    url: str
    query: str
    caseSensitive: bool | None = None
    isRegex: bool | None = None


class SearchInResourceOutput(OutputModel):

    result: list[Debugger.SearchMatch]


class SearchInResource(CDPMethod[SearchInResourceOutput]):  # experimental
    """ Searches for given string in resource content. """

    INPUT_VALIDATOR = SearchInResourceInput
    OUTPUT_VALIDATOR = SearchInResourceOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId,
        url: str,
        query: str,
        case_sensitive: bool | None = None,
        is_regex: bool | None = None
    ):
        super().__init__(
            frameId=frame_id,
            url=url,
            query=query,
            caseSensitive=case_sensitive,
            isRegex=is_regex
        )


class SetAdBlockingEnabledInput(InputModel):

    enabled: bool


class SetAdBlockingEnabled(CDPMethod[None]):  # experimental
    """ Enable Chrome's experimental ad filter on all sites. """

    INPUT_VALIDATOR = SetAdBlockingEnabledInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool
    ):
        super().__init__(
            enabled=enabled
        )


class SetBypassCSPInput(InputModel):

    enabled: bool


class SetBypassCSP(CDPMethod[None]):
    """ Enable page Content Security Policy by-passing. """

    INPUT_VALIDATOR = SetBypassCSPInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool
    ):
        super().__init__(
            enabled=enabled
        )


class GetPermissionsPolicyStateInput(InputModel):

    frameId: Page.FrameId


class GetPermissionsPolicyStateOutput(OutputModel):

    states: list[Page.PermissionsPolicyFeatureState]


class GetPermissionsPolicyState(CDPMethod[GetPermissionsPolicyStateOutput]):  # experimental
    """ Get Permissions Policy state on given frame. """

    INPUT_VALIDATOR = GetPermissionsPolicyStateInput
    OUTPUT_VALIDATOR = GetPermissionsPolicyStateOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId
    ):
        super().__init__(
            frameId=frame_id
        )


class GetOriginTrialsInput(InputModel):

    frameId: Page.FrameId


class GetOriginTrialsOutput(OutputModel):

    originTrials: list[Page.OriginTrial]


class GetOriginTrials(CDPMethod[GetOriginTrialsOutput]):  # experimental
    """ Get Origin Trials on given frame. """

    INPUT_VALIDATOR = GetOriginTrialsInput
    OUTPUT_VALIDATOR = GetOriginTrialsOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId
    ):
        super().__init__(
            frameId=frame_id
        )


class SetDeviceMetricsOverrideInput(InputModel):

    width: int
    height: int
    deviceScaleFactor: float
    mobile: bool
    scale: float | None = None
    screenWidth: int | None = None
    screenHeight: int | None = None
    positionX: int | None = None
    positionY: int | None = None
    dontSetVisibleSize: bool | None = None
    screenOrientation: Emulation.ScreenOrientation | None = None
    viewport: Page.Viewport | None = None


class SetDeviceMetricsOverride(CDPMethod[None]):  # experimental deprecated
    """ Overrides the values of device screen dimensions (window.screen.width, window.screen.height,
    window.innerWidth, window.innerHeight, and "device-width"/"device-height"-related CSS media
    query results). """

    INPUT_VALIDATOR = SetDeviceMetricsOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        width: int,
        height: int,
        device_scale_factor: float,
        mobile: bool,
        scale: float | None = None,
        screen_width: int | None = None,
        screen_height: int | None = None,
        position_x: int | None = None,
        position_y: int | None = None,
        dont_set_visible_size: bool | None = None,
        screen_orientation: Emulation.ScreenOrientation | None = None,
        viewport: Page.Viewport | None = None
    ):
        super().__init__(
            width=width,
            height=height,
            deviceScaleFactor=device_scale_factor,
            mobile=mobile,
            scale=scale,
            screenWidth=screen_width,
            screenHeight=screen_height,
            positionX=position_x,
            positionY=position_y,
            dontSetVisibleSize=dont_set_visible_size,
            screenOrientation=screen_orientation,
            viewport=viewport
        )


class SetDeviceOrientationOverrideInput(InputModel):

    alpha: float
    beta: float
    gamma: float


class SetDeviceOrientationOverride(CDPMethod[None]):  # experimental deprecated
    """ Overrides the Device Orientation. """

    INPUT_VALIDATOR = SetDeviceOrientationOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        alpha: float,
        beta: float,
        gamma: float
    ):
        super().__init__(
            alpha=alpha,
            beta=beta,
            gamma=gamma
        )


class SetFontFamiliesInput(InputModel):

    fontFamilies: Page.FontFamilies
    forScripts: list[Page.ScriptFontFamilies] | None = None


class SetFontFamilies(CDPMethod[None]):  # experimental
    """ Set generic font families. """

    INPUT_VALIDATOR = SetFontFamiliesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        font_families: Page.FontFamilies,
        for_scripts: list[Page.ScriptFontFamilies] | None = None
    ):
        super().__init__(
            fontFamilies=font_families,
            forScripts=for_scripts
        )


class SetFontSizesInput(InputModel):

    fontSizes: Page.FontSizes


class SetFontSizes(CDPMethod[None]):  # experimental
    """ Set default font sizes. """

    INPUT_VALIDATOR = SetFontSizesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        font_sizes: Page.FontSizes
    ):
        super().__init__(
            fontSizes=font_sizes
        )


class SetDocumentContentInput(InputModel):

    frameId: Page.FrameId
    html: str


class SetDocumentContent(CDPMethod[None]):
    """ Sets given markup as the document's HTML. """

    INPUT_VALIDATOR = SetDocumentContentInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        frame_id: Page.FrameId,
        html: str
    ):
        super().__init__(
            frameId=frame_id,
            html=html
        )


class SetDownloadBehaviorInput(InputModel):

    behavior: Literal['deny', 'allow', 'default']
    downloadPath: str | None = None


class SetDownloadBehavior(CDPMethod[None]):  # experimental deprecated
    """ Set the behavior when downloading a file. """

    INPUT_VALIDATOR = SetDownloadBehaviorInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        behavior: Literal['deny', 'allow', 'default'],
        download_path: str | None = None
    ):
        super().__init__(
            behavior=behavior,
            downloadPath=download_path
        )


class SetGeolocationOverrideInput(InputModel):

    latitude: float | None = None
    longitude: float | None = None
    accuracy: float | None = None


class SetGeolocationOverride(CDPMethod[None]):  # deprecated
    """ Overrides the Geolocation Position or Error. Omitting any of the parameters emulates position
    unavailable. """

    INPUT_VALIDATOR = SetGeolocationOverrideInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        latitude: float | None = None,
        longitude: float | None = None,
        accuracy: float | None = None
    ):
        super().__init__(
            latitude=latitude,
            longitude=longitude,
            accuracy=accuracy
        )


class SetLifecycleEventsEnabledInput(InputModel):

    enabled: bool


class SetLifecycleEventsEnabled(CDPMethod[None]):
    """ Controls whether page will emit lifecycle events. """

    INPUT_VALIDATOR = SetLifecycleEventsEnabledInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool
    ):
        super().__init__(
            enabled=enabled
        )


class SetTouchEmulationEnabledInput(InputModel):

    enabled: bool
    configuration: Literal['mobile', 'desktop'] | None = None


class SetTouchEmulationEnabled(CDPMethod[None]):  # experimental deprecated
    """ Toggles mouse event-based touch event emulation. """

    INPUT_VALIDATOR = SetTouchEmulationEnabledInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool,
        configuration: Literal['mobile', 'desktop'] | None = None
    ):
        super().__init__(
            enabled=enabled,
            configuration=configuration
        )


class StartScreencastInput(InputModel):

    format: Literal['jpeg', 'png'] | None = None
    quality: int | None = None
    maxWidth: int | None = None
    maxHeight: int | None = None
    everyNthFrame: int | None = None


class StartScreencast(CDPMethod[None]):  # experimental
    """ Starts sending each frame using the `screencastFrame` event. """

    INPUT_VALIDATOR = StartScreencastInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        format_: Literal['jpeg', 'png'] | None = None,
        quality: int | None = None,
        max_width: int | None = None,
        max_height: int | None = None,
        every_nth_frame: int | None = None
    ):
        super().__init__(
            format=format_,
            quality=quality,
            maxWidth=max_width,
            maxHeight=max_height,
            everyNthFrame=every_nth_frame
        )


class StopLoading(CDPMethod[None]):
    """ Force the page stop all navigations and pending resource fetches. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Crash(CDPMethod[None]):  # experimental
    """ Crashes renderer on the IO thread, generates minidumps. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Close(CDPMethod[None]):
    """ Tries to close page, running its beforeunload hooks, if any. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class SetWebLifecycleStateInput(InputModel):

    state: Literal['frozen', 'active']


class SetWebLifecycleState(CDPMethod[None]):  # experimental
    """ Tries to update the web lifecycle state of the page.
    It will transition the page to the given state according to:
    https://github.com/WICG/web-lifecycle/ """

    INPUT_VALIDATOR = SetWebLifecycleStateInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        state: Literal['frozen', 'active']
    ):
        super().__init__(
            state=state
        )


class StopScreencast(CDPMethod[None]):  # experimental
    """ Stops sending each frame in the `screencastFrame`. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class ProduceCompilationCacheInput(InputModel):

    scripts: list[Page.CompilationCacheParams]


class ProduceCompilationCache(CDPMethod[None]):  # experimental
    """ Requests backend to produce compilation cache for the specified scripts.
    `scripts` are appended to the list of scripts for which the cache
    would be produced. The list may be reset during page navigation.
    When script with a matching URL is encountered, the cache is optionally
    produced upon backend discretion, based on internal heuristics.
    See also: `Page.compilationCacheProduced`. """

    INPUT_VALIDATOR = ProduceCompilationCacheInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        scripts: list[Page.CompilationCacheParams]
    ):
        super().__init__(
            scripts=scripts
        )


class AddCompilationCacheInput(InputModel):

    url: str
    data: str


class AddCompilationCache(CDPMethod[None]):  # experimental
    """ Seeds compilation cache for given url. Compilation cache does not survive
    cross-process navigation. """

    INPUT_VALIDATOR = AddCompilationCacheInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        url: str,
        data: str
    ):
        super().__init__(
            url=url,
            data=data
        )


class ClearCompilationCache(CDPMethod[None]):  # experimental
    """ Clears seeded compilation cache. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class SetSPCTransactionModeInput(InputModel):

    mode: Literal['none', 'autoAccept', 'autoChooseToAuthAnotherWay', 'autoReject', 'autoOptOut']


class SetSPCTransactionMode(CDPMethod[None]):  # experimental
    """ Sets the Secure Payment Confirmation transaction mode.
    https://w3c.github.io/secure-payment-confirmation/#sctn-automation-set-spc-transaction-mode """

    INPUT_VALIDATOR = SetSPCTransactionModeInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        mode: Literal['none', 'autoAccept', 'autoChooseToAuthAnotherWay', 'autoReject', 'autoOptOut']
    ):
        super().__init__(
            mode=mode
        )


class SetRPHRegistrationModeInput(InputModel):

    mode: Literal['none', 'autoAccept', 'autoReject']


class SetRPHRegistrationMode(CDPMethod[None]):  # experimental
    """ Extensions for Custom Handlers API:
    https://html.spec.whatwg.org/multipage/system-state.html#rph-automation """

    INPUT_VALIDATOR = SetRPHRegistrationModeInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        mode: Literal['none', 'autoAccept', 'autoReject']
    ):
        super().__init__(
            mode=mode
        )


class GenerateTestReportInput(InputModel):

    message: str
    group: str | None = None


class GenerateTestReport(CDPMethod[None]):  # experimental
    """ Generates a report for testing. """

    INPUT_VALIDATOR = GenerateTestReportInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        message: str,
        group: str | None = None
    ):
        super().__init__(
            message=message,
            group=group
        )


class WaitForDebugger(CDPMethod[None]):  # experimental
    """ Pauses page execution. Can be resumed using generic Runtime.runIfWaitingForDebugger. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class SetInterceptFileChooserDialogInput(InputModel):

    enabled: bool
    cancel: bool | None = None  # experimental


class SetInterceptFileChooserDialog(CDPMethod[None]):
    """ Intercept file chooser requests and transfer control to protocol clients.
    When file chooser interception is enabled, native file chooser dialog is not shown.
    Instead, a protocol event `Page.fileChooserOpened` is emitted. """

    INPUT_VALIDATOR = SetInterceptFileChooserDialogInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool,
        cancel: bool | None = None
    ):
        super().__init__(
            enabled=enabled,
            cancel=cancel
        )


class SetPrerenderingAllowedInput(InputModel):

    isAllowed: bool


class SetPrerenderingAllowed(CDPMethod[None]):  # experimental
    """ Enable/disable prerendering manually.

    This command is a short-term solution for https://crbug.com/1440085.
    See https://docs.google.com/document/d/12HVmFxYj5Jc-eJr5OmWsa2bqTJsbgGLKI6ZIyx0_wpA
    for more details.

    TODO(https://crbug.com/1440085): Remove this once Puppeteer supports tab targets. """

    INPUT_VALIDATOR = SetPrerenderingAllowedInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        is_allowed: bool
    ):
        super().__init__(
            isAllowed=is_allowed
        )


class GetAnnotatedPageContentInput(InputModel):

    includeActionableInformation: bool | None = None


class GetAnnotatedPageContentOutput(OutputModel):

    content: str


class GetAnnotatedPageContent(CDPMethod[GetAnnotatedPageContentOutput]):  # experimental
    """ Get the annotated page content for the main frame.
    This is an experimental command that is subject to change. """

    INPUT_VALIDATOR = GetAnnotatedPageContentInput
    OUTPUT_VALIDATOR = GetAnnotatedPageContentOutput

    def __init__(
        self,
        *,
        include_actionable_information: bool | None = None
    ):
        super().__init__(
            includeActionableInformation=include_actionable_information
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Input/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Input,
)
from cdpkit.protocol.base import CDPEvent


class DragIntercepted(CDPEvent):
    """ Emitted only when `Input.setInterceptDrags` is enabled. Use this data with `Input.dispatchDragEvent` to
    restore normal drag and drop behavior. """

    data: Input.DragData



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Input/Output operations for streams produced by DevTools.
https://chromedevtools.github.io/devtools-protocol/tot/IO/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    IOStreamHandle,
)

StreamHandle = IOStreamHandle



from .events import InspectModeCanceled, InspectNodeRequested, NodeHighlightRequested, ScreenshotRequested
from .methods import (
    Disable,
    Enable,
    GetGridHighlightObjectsForTest,
    GetHighlightObjectForTest,
    GetSourceOrderHighlightObjectForTest,
    HideHighlight,
    HighlightFrame,
    HighlightNode,
    HighlightQuad,
    HighlightRect,
    HighlightSourceOrder,
    SetInspectMode,
    SetPausedInDebuggerMessage,
    SetShowAdHighlights,
    SetShowContainerQueryOverlays,
    SetShowDebugBorders,
    SetShowFlexOverlays,
    SetShowFPSCounter,
    SetShowGridOverlays,
    SetShowHinge,
    SetShowHitTestBorders,
    SetShowIsolatedElements,
    SetShowLayoutShiftRegions,
    SetShowPaintRects,
    SetShowScrollBottleneckRects,
    SetShowScrollSnapOverlays,
    SetShowViewportSizeOnResize,
    SetShowWebVitals,
    SetShowWindowControlsOverlay,
)
from .types import (
    BoxStyle,
    ColorFormat,
    ContainerQueryContainerHighlightConfig,
    ContainerQueryHighlightConfig,
    ContrastAlgorithm,
    FlexContainerHighlightConfig,
    FlexItemHighlightConfig,
    FlexNodeHighlightConfig,
    GridHighlightConfig,
    GridNodeHighlightConfig,
    HighlightConfig,
    HingeConfig,
    InspectMode,
    IsolatedElementHighlightConfig,
    IsolationModeHighlightConfig,
    LineStyle,
    ScrollSnapContainerHighlightConfig,
    ScrollSnapHighlightConfig,
    SourceOrderConfig,
    WindowControlsOverlayConfig,
)

__all__ = [
    SourceOrderConfig,
    GridHighlightConfig,
    FlexContainerHighlightConfig,
    FlexItemHighlightConfig,
    LineStyle,
    BoxStyle,
    ContrastAlgorithm,
    HighlightConfig,
    ColorFormat,
    GridNodeHighlightConfig,
    FlexNodeHighlightConfig,
    ScrollSnapContainerHighlightConfig,
    ScrollSnapHighlightConfig,
    HingeConfig,
    WindowControlsOverlayConfig,
    ContainerQueryHighlightConfig,
    ContainerQueryContainerHighlightConfig,
    IsolatedElementHighlightConfig,
    IsolationModeHighlightConfig,
    InspectMode,
    InspectNodeRequested,
    NodeHighlightRequested,
    ScreenshotRequested,
    InspectModeCanceled,
    Disable,
    Enable,
    GetHighlightObjectForTest,
    GetGridHighlightObjectsForTest,
    GetSourceOrderHighlightObjectForTest,
    HideHighlight,
    HighlightFrame,
    HighlightNode,
    HighlightQuad,
    HighlightRect,
    HighlightSourceOrder,
    SetInspectMode,
    SetShowAdHighlights,
    SetPausedInDebuggerMessage,
    SetShowDebugBorders,
    SetShowFPSCounter,
    SetShowGridOverlays,
    SetShowFlexOverlays,
    SetShowScrollSnapOverlays,
    SetShowContainerQueryOverlays,
    SetShowPaintRects,
    SetShowLayoutShiftRegions,
    SetShowScrollBottleneckRects,
    SetShowHitTestBorders,
    SetShowWebVitals,
    SetShowViewportSizeOnResize,
    SetShowHinge,
    SetShowIsolatedElements,
    SetShowWindowControlsOverlay,
]



from .events import (
    BindingCalled,
    ConsoleAPICalled,
    ExceptionRevoked,
    ExceptionThrown,
    ExecutionContextCreated,
    ExecutionContextDestroyed,
    ExecutionContextsCleared,
    InspectRequested,
)
from .methods import (
    AddBinding,
    AwaitPromise,
    CallFunctionOn,
    CompileScript,
    Disable,
    DiscardConsoleEntries,
    Enable,
    Evaluate,
    GetExceptionDetails,
    GetHeapUsage,
    GetIsolateId,
    GetProperties,
    GlobalLexicalScopeNames,
    QueryObjects,
    ReleaseObject,
    ReleaseObjectGroup,
    RemoveBinding,
    RunIfWaitingForDebugger,
    RunScript,
    SetAsyncCallStackDepth,
    SetCustomObjectFormatterEnabled,
    SetMaxCallStackSizeToCapture,
    TerminateExecution,
)
from .types import (
    CallArgument,
    CallFrame,
    CustomPreview,
    DeepSerializedValue,
    EntryPreview,
    ExceptionDetails,
    ExecutionContextDescription,
    ExecutionContextId,
    InternalPropertyDescriptor,
    ObjectPreview,
    PrivatePropertyDescriptor,
    PropertyDescriptor,
    PropertyPreview,
    RemoteObject,
    RemoteObjectId,
    ScriptId,
    SerializationOptions,
    StackTrace,
    StackTraceId,
    TimeDelta,
    Timestamp,
    UniqueDebuggerId,
    UnserializableValue,
)

__all__ = [
    ScriptId,
    SerializationOptions,
    DeepSerializedValue,
    RemoteObjectId,
    UnserializableValue,
    RemoteObject,
    CustomPreview,
    ObjectPreview,
    PropertyPreview,
    EntryPreview,
    PropertyDescriptor,
    InternalPropertyDescriptor,
    PrivatePropertyDescriptor,
    CallArgument,
    ExecutionContextId,
    ExecutionContextDescription,
    ExceptionDetails,
    Timestamp,
    TimeDelta,
    CallFrame,
    StackTrace,
    UniqueDebuggerId,
    StackTraceId,
    BindingCalled,
    ConsoleAPICalled,
    ExceptionRevoked,
    ExceptionThrown,
    ExecutionContextCreated,
    ExecutionContextDestroyed,
    ExecutionContextsCleared,
    InspectRequested,
    AwaitPromise,
    CallFunctionOn,
    CompileScript,
    Disable,
    DiscardConsoleEntries,
    Enable,
    Evaluate,
    GetIsolateId,
    GetHeapUsage,
    GetProperties,
    GlobalLexicalScopeNames,
    QueryObjects,
    ReleaseObject,
    ReleaseObjectGroup,
    RunIfWaitingForDebugger,
    RunScript,
    SetAsyncCallStackDepth,
    SetCustomObjectFormatterEnabled,
    SetMaxCallStackSizeToCapture,
    TerminateExecution,
    AddBinding,
    RemoveBinding,
    GetExceptionDetails,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Reporting of performance timeline events, as specified in
https://w3c.github.io/performance-timeline/#dom-performanceobserver.
https://chromedevtools.github.io/devtools-protocol/tot/PerformanceTimeline/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    PerformanceTimeline,
)
from cdpkit.protocol.base import CDPEvent


class TimelineEventAdded(CDPEvent):
    """ Sent when a performance timeline event is added. See reportPerformanceTimeline method. """

    event: PerformanceTimeline.TimelineEvent
